package com.gic.spark.datasource.entity;

import com.gic.sharding.sdk.ShardingConfigManager;
import com.gic.sharding.sdk.entity.ShardingConfig;
import com.gic.spark.application.SparkEnvManager;
import com.gic.spark.datasource.sharding.ShardingRddManager;
import com.gic.spark.util.HivePartitionUtil;
import com.gic.spark.util.SparkHiveUtil;
import org.apache.spark.sql.Column;
import org.apache.spark.sql.Dataset;
import org.apache.spark.sql.Row;
import org.apache.spark.sql.SparkSession;

import java.util.List;

/**
 * Created by paste on 2018/7/27 16:58
 * <p>
 * TODO: class description
 */
public class DataSourceSharding extends DataSourceEntity {
    private ShardingConfig shardingConfig;
    private String targetTable;
    private String configName;
    public DataSourceSharding(String configName, String targetTable) {

        System.out.println("configName==>"+configName+" ,targetTable==>"+targetTable);
        this.configName=configName;
        sourceType = DataSourceType.MYSQL_SHARDING;
        this.shardingConfig = ShardingConfigManager.getInstance().getCurrentShardingConfig(configName);
        this.targetTable = targetTable;
    }

    public ShardingConfig getShardingConfig() {
        return shardingConfig;
    }

    public void setShardingConfig(ShardingConfig shardingConfig) {
        this.shardingConfig = shardingConfig;
    }

    private void checkShardingConfigInit(){
        if(null==getShardingConfig()){
            throw new RuntimeException("configName ["+this.configName+"] create ShardingConfig fail !");
        }
    }
    @Override
    public String getSourceKey() {
        this.checkShardingConfigInit();
        System.out.println("name==>"+sourceType.getName()+" ,id==>"+shardingConfig.get_id()+" ,targetTable==>"+targetTable);
        return sourceType.getName() + "_" + shardingConfig.get_id() + "_" + targetTable;
    }

    @Override
    public String getHiveTableName() {
        this.checkShardingConfigInit();
        return getSchema()+"." + shardingConfig.get_id().replaceAll("\\.", "_") + "_" + targetTable;
    }

    @Override
    public void extractDataToPartitionedHiveTable(List<Integer> enterpriseList) {
        this.checkShardingConfigInit();
        SparkSession sparkSession = SparkEnvManager.getInstance().getSparkSession();
        ShardingRddManager shardingRddManager = new ShardingRddManager(shardingConfig,sparkSession);
        Dataset<Row> sourceDataset = shardingRddManager.getDatasetByEnterpriseIds(targetTable, enterpriseList, null, null).repartition(new Column("enterprise_id"));
        SparkHiveUtil.createHivePartitionTable(sourceDataset, "enterprise_id", getSchema(), shardingConfig.get_id().replaceAll("\\.", "_") + "_" + targetTable,sparkSession);

        HivePartitionUtil.saveDatasetToPartitionTable(sparkSession, sourceDataset, getHiveTableName());

    }
}
