package com.gic.spark.filter;

import com.gic.spark.datasource.entity.DataSourceEntity;
import com.gic.spark.datasource.entity.DataSourceSharding;
import com.gic.spark.datasource.mysql.MysqlRddManager;
import com.gic.spark.entity.bean.TagIntegralBean;
import com.gic.spark.entity.request.AbstractFilterRequest;
import com.gic.spark.entity.request.TagIntegralRequest;
import com.gic.spark.tag.TagConstant;
import com.gic.spark.util.AppEnvUtil;
import com.gic.spark.util.ConstantUtil;
import com.gic.spark.util.DateUtil;
import org.apache.spark.api.java.JavaRDD;
import org.apache.spark.sql.Column;
import org.apache.spark.sql.Dataset;
import org.apache.spark.sql.Row;
import scala.Tuple2;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

/**
 * @description:
 * @author: wangxk
 * @date: 2020/4/24
 */
public class TagAccumulatedIntegralFilter implements BaseTagFilter {

    private DataSourceSharding dataSourceSharding=new DataSourceSharding(AppEnvUtil.MEMBER_SHARDING_4, ConstantUtil.TAB_INTEGRAL_CU_CHANGE_LOG);
    private static TagAccumulatedIntegralFilter instance;
    public static TagAccumulatedIntegralFilter getInstance() {
            if(null==instance){
                instance=new TagAccumulatedIntegralFilter();
            }
        return instance;
    }

    private TagAccumulatedIntegralFilter(){}

    @Override
    public List<DataSourceEntity> necessarySourceList() {
        List<DataSourceEntity> result = new ArrayList();
        result.add(dataSourceSharding);
        return result;
    }

    @Override
    public JavaRDD<Long> filterValidMember(Integer enterpriseId, AbstractFilterRequest request) {
        TagIntegralRequest integralRequest=(TagIntegralRequest)request;
        Dataset<Row> dataset=dataSourceSharding.getDatasetByEnterpriseId(enterpriseId)
                                            .filter(new Column("create_Time").isNotNull());
        JavaRDD<TagIntegralBean>integralRDD=MysqlRddManager.getPojoFromDataset(dataset,TagIntegralBean.class).javaRDD();

        JavaRDD<Long>ecuRdd=integralRDD.mapPartitions(data->{
                                                List<TagIntegralBean>result=new ArrayList();
                                                while (data.hasNext()){
                                                    TagIntegralBean integralBean=data.next();
                                                    switch (integralRequest.getDomainType()){
                                                        case ACU_INFO:
                                                            if(TagConstant.CU_TYPE_ACU==integralBean.getCu_Type()
                                                                    &&integralRequest.getCuVals().contains(integralBean.getCu_Id())){
                                                                result.add(integralBean);
                                                            }
                                                            break;
                                                        case SCU_INFO:
                                                            if(TagConstant.CU_TYPE_SCU==integralBean.getCu_Type()
                                                                    &&integralRequest.getCuVals().contains(integralBean.getCu_Id())){
                                                                result.add(integralBean);
                                                            }
                                                            break;
                                                        case MCU_INFO:
                                                            if(TagConstant.CU_TYPE_MCU==integralBean.getCu_Type()
                                                                    &&integralRequest.getCuVals().contains(integralBean.getCu_Id())){
                                                                result.add(integralBean);
                                                            }
                                                            break;
                                                        default:break;
                                                    }
                                                }
                                                return result.iterator();
                                            }).mapPartitions(data->{
                                                List<TagIntegralBean>result=new ArrayList();
                                                while (data.hasNext()){
                                                    TagIntegralBean integralBean=data.next();
                                                    switch (integralRequest.getTimeRangeType()){
                                                        case LATELY:
                                                                if(integralBean.getCreate_Time().getTime()>
                                                                        DateUtil.addNumForDay(DateUtil.getDate(),integralRequest.getTimeNum()).getTime()){
                                                                    result.add(integralBean);
                                                                }
                                                            break;
                                                        case FIXATION:
                                                                if(integralBean.getCreate_Time().getTime()>=integralRequest.getBeginTime().getTime()
                                                                        &&integralBean.getCreate_Time().getTime()<=integralRequest.getEndTime().getTime()){
                                                                    result.add(integralBean);
                                                                }
                                                            break;

                                                        default:break;
                                                    }
                                                }
                                                return result.iterator();
                                            }).mapToPair(data-> Tuple2.apply(data.getCu_Id()+"@"+data.getFile_ecu_id(),data)).groupByKey()
                                              .mapPartitions(data->{
                                                  Set<Long>result=new HashSet();
                                                    while (data.hasNext()){
                                                        Tuple2<String,Iterable<TagIntegralBean>> tp2=data.next();
                                                        int integralValue=0;
                                                        for(TagIntegralBean integralBean:tp2._2()){
                                                            integralValue+=integralBean.getIntegral_Value()>0?integralBean.getIntegral_Value():0;
                                                        }
                                                        switch (integralRequest.getNumberType()){
                                                            case eq:
                                                                if(integralRequest.getEqualNum()==integralValue){
                                                                    result.add(Long.parseLong(tp2._1().split("@")[1]));
                                                                }
                                                                break;
                                                            case gt:
                                                                if(integralValue>integralRequest.getBeginNum()){
                                                                    result.add(Long.parseLong(tp2._1().split("@")[1]));
                                                                }
                                                                break;
                                                            case gte:
                                                                if(integralValue>=integralRequest.getBeginNum()){
                                                                    result.add(Long.parseLong(tp2._1().split("@")[1]));
                                                                }
                                                                break;
                                                            case lt:
                                                                if(integralValue<integralRequest.getEndNum()){
                                                                    result.add(Long.parseLong(tp2._1().split("@")[1]));
                                                                }
                                                                break;
                                                            case lte:
                                                                if(integralValue<=integralRequest.getEndNum()){
                                                                    result.add(Long.parseLong(tp2._1().split("@")[1]));
                                                                }
                                                                break;
                                                            case between:
                                                                if(integralValue>=integralRequest.getBeginNum()
                                                                        &&integralValue<=integralRequest.getEndNum()){
                                                                    result.add(Long.parseLong(tp2._1().split("@")[1]));
                                                                }
                                                                break;
                                                            default:break;
                                                        }
                                                    }
                                                  return result.iterator();
                                            });

        return ecuRdd;
    }
}
