package com.gic.spark.filter;

import com.gic.spark.datasource.entity.DataSourceEntity;
import com.gic.spark.datasource.mysql.MysqlRddManager;
import com.gic.spark.entity.bean.TrdEcuSalesLabelBean;
import com.gic.spark.entity.request.AbstractFilterRequest;
import com.gic.spark.entity.request.TagConsumeRequest;
import org.apache.spark.api.java.JavaRDD;
import scala.Tuple2;

import java.util.ArrayList;
import java.util.List;

/**
 * @description:
 * 平均折扣率
 * @author: wangxk
 * @date: 2020/5/7
 */
public class TagAverageDiscountFactorFilter extends AbstractTagConsumFilter {

    private static TagAverageDiscountFactorFilter instance;
    public static TagAverageDiscountFactorFilter getInstance() {
        if(null==instance){
            instance=new TagAverageDiscountFactorFilter();
        }
        return instance;
    }
    private TagAverageDiscountFactorFilter(){}


    @Override
    public List<DataSourceEntity> necessarySourceList() {
        List<DataSourceEntity> result = new ArrayList();
        result.add(dataSourceHive);
        return result;
    }

    @Override
    public JavaRDD<Long> filterValidMember(Integer enterpriseId, AbstractFilterRequest request) {
        TagConsumeRequest consumeRequest=(TagConsumeRequest)request;
        JavaRDD<TrdEcuSalesLabelBean> consumeRDD= MysqlRddManager.getPojoFromDataset(dataSourceHive.getDatasetByEntId(enterpriseId), TrdEcuSalesLabelBean.class).javaRDD();
        consumeRDD=statisticsTypeHandle(consumeRDD,consumeRequest);
        JavaRDD<Long>ecuRdd=consumeRDD.mapToPair(data-> Tuple2.apply(data.getEcu_id(),data)).groupByKey()
                                        .mapPartitions(data->{
                                           List<Long>result=new ArrayList();
                                           while (data.hasNext()){
                                               double payAmt=0;
                                               double totalAmt=0;
                                               Tuple2<Long,Iterable<TrdEcuSalesLabelBean>> tp2=data.next();
                                               for(TrdEcuSalesLabelBean consumeBean:tp2._2()){
                                                   payAmt=consumeBean.getPay_amt();
                                                   totalAmt=consumeBean.getTotal_amt();
                                               }
                                               double avgDiscountRate=payAmt/totalAmt;
                                               switch (consumeRequest.getNumberType()){
                                                   case gt:
                                                       if(avgDiscountRate>consumeRequest.getBeginNum()){
                                                           result.add(tp2._1());
                                                       }
                                                       break;
                                                   case gte:
                                                       if(avgDiscountRate>=consumeRequest.getBeginNum()){
                                                           result.add(tp2._1());
                                                       }
                                                       break;
                                                   case lt:
                                                       if(avgDiscountRate<consumeRequest.getEndNum()){
                                                           result.add(tp2._1());
                                                       }
                                                       break;
                                                   case lte:
                                                       if(avgDiscountRate<=consumeRequest.getEndNum()){
                                                           result.add(tp2._1());
                                                       }
                                                       break;
                                                   case eq:
                                                       if(avgDiscountRate==consumeRequest.getEqualNum()){
                                                           result.add(tp2._1());
                                                       }
                                                       break;
                                                   case between:
                                                       if(avgDiscountRate>=consumeRequest.getBeginNum()
                                                               &&avgDiscountRate<=consumeRequest.getEndNum()){
                                                           result.add(tp2._1());
                                                       }
                                                   default:break;
                                               }
                                           }
                                           return result.iterator();
                                        });
        return ecuRdd;
    }
}
