package com.gic.spark.filter;

import com.gic.spark.datasource.entity.DataSourceEntity;
import com.gic.spark.datasource.mysql.MysqlRddManager;
import com.gic.spark.entity.bean.TrdVirtualOrderBean;
import com.gic.spark.entity.request.AbstractFilterRequest;
import com.gic.spark.entity.request.TagConsumeAmountRequest;
import com.gic.spark.util.CommonUtil;
import com.gic.spark.util.DateUtil;
import org.apache.commons.lang3.StringUtils;
import org.apache.spark.api.java.JavaRDD;
import scala.Tuple2;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * @description:
 * @author: wangxk
 * @date: 2020/8/3
 */
public class TagConsumeTotalFilter extends AbstractTagConsumRecordFilter {

    private static TagConsumeTotalFilter instance;
    public static TagConsumeTotalFilter  getInstance(){
        if(null==instance){
            instance=new TagConsumeTotalFilter();
        }
        return instance;
    }
    private TagConsumeTotalFilter(){}

    @Override
    public List<DataSourceEntity> necessarySourceList() {
        List<DataSourceEntity> result = new ArrayList();
        result.add(dataSourceHive);
        return result;
    }

    @Override
    public JavaRDD<Long> filterValidMember(Integer enterpriseId, AbstractFilterRequest request) {
        TagConsumeAmountRequest consumeAmountRequest=(TagConsumeAmountRequest)request;
        JavaRDD<TrdVirtualOrderBean>consumeRecordRDD=MysqlRddManager.getPojoFromDataset(dataSourceHive.getDatasetByEntId(enterpriseId), TrdVirtualOrderBean.class).javaRDD();
        consumeRecordRDD=statisticsTypeHandle(consumeRecordRDD,consumeAmountRequest);

        int configStatus= CommonUtil.getConfigStatus(enterpriseId);
        JavaRDD<Long>ecuRdd=consumeRecordRDD.filter(data->{
                                                boolean result=false;
                                                if(StringUtils.isNotEmpty(data.getReceipts_time())){
                                                    Date receiptsTime=DateUtil.strToDate(data.getReceipts_time(),DateUtil.FORMAT_DATE_10);
                                                    switch (consumeAmountRequest.getTimeRangeType()){
                                                        case FIXATION:
                                                            if(receiptsTime.getTime()>=consumeAmountRequest.getBeginTime().getTime()
                                                                &&receiptsTime.getTime()<=consumeAmountRequest.getEndTime().getTime())
                                                                result=true;
                                                            break;
                                                        case LATELY:
                                                                if(receiptsTime.getTime()>DateUtil.addNumForDay(new Date(),consumeAmountRequest.getTimeNum()).getTime()){
                                                                    result=true;
                                                                }
                                                            break;
                                                        default:break;
                                                    }
                                                }
                                                return result;
                                            }).mapToPair(data-> Tuple2.apply(data.getEcu_id(),configStatus==1?data.getPaid_amt():data.getPay_amt()))
                                            .reduceByKey((x,y)->x+y)
                                            .filter(data->{
                                                boolean result=false;
                                                switch (consumeAmountRequest.getNumberType()){
                                                    case between:
                                                         if(data._2()>=consumeAmountRequest.getBeginNum()
                                                             &&data._2()<=consumeAmountRequest.getEndNum()){
                                                             result=true;
                                                         }
                                                        break;
                                                    case lt:
                                                        if(data._2()<consumeAmountRequest.getEndNum()){
                                                            result=true;
                                                        }
                                                        break;
                                                    case gt:
                                                        if(data._2()>consumeAmountRequest.getBeginNum()){
                                                            result=true;
                                                        }
                                                        break;
                                                    case eq:
                                                        if(data._2()==consumeAmountRequest.getEqualNum()){
                                                            result=true;
                                                        }
                                                        break;
                                                    case lte:
                                                        if(data._2()<=consumeAmountRequest.getEndNum()){
                                                            result=true;
                                                        }
                                                        break;
                                                    case gte:
                                                        if(data._2()>=consumeAmountRequest.getBeginNum()){
                                                            result=true;
                                                        }
                                                        break;
                                                    default:break;
                                                }
                                                return result;
                                            }).map(data->data._1());

        return ecuRdd;
    }
}
