package com.gic.spark.filter;

import com.gic.spark.datasource.entity.DataSourceEntity;
import com.gic.spark.datasource.entity.DataSourceSharding;
import com.gic.spark.datasource.mysql.MysqlRddManager;
import com.gic.spark.entity.bean.TagCouponBean;
import com.gic.spark.entity.request.TagCouponRequest;
import com.gic.spark.entity.request.AbstractFilterRequest;
import com.gic.spark.util.AppEnvUtil;
import com.gic.spark.util.ConstantUtil;
import org.apache.spark.api.java.JavaRDD;
import org.apache.spark.sql.Column;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

/**
 * @description:
 * @author: wangxk
 * @date: 2020/4/29
 */
public class TagCouponFilter implements BaseTagFilter {

    private DataSourceSharding dataSourceSharding=new DataSourceSharding(AppEnvUtil.MARKETING_SHARDING, ConstantUtil.TAB_COUPON_LOG);
    private static TagCouponFilter instance;
    public static TagCouponFilter getInstance(){
        if(null==instance){
            instance=new TagCouponFilter();
        }
        return instance;
    }
    private TagCouponFilter(){}

    @Override
    public List<DataSourceEntity> necessarySourceList() {
        List<DataSourceEntity> result = new ArrayList();
        result.add(dataSourceSharding);
        return result;
    }

    @Override
    public JavaRDD<Long> filterValidMember(Integer enterpriseId, AbstractFilterRequest request) {
        TagCouponRequest couponRequest=(TagCouponRequest)request;
        JavaRDD<TagCouponBean> couponBeanRDD= MysqlRddManager.getPojoFromDataset(dataSourceSharding.getDatasetByEnterpriseId(enterpriseId)
                                                            .filter(new Column("status").isNotNull()),TagCouponBean.class).javaRDD()
                                                            .filter(data->couponRequest.getCouponList().contains(data.getCoupon_id()));
        JavaRDD<Long>ecuRDD=couponBeanRDD.mapPartitions(data->{
                                                Set<Long>result=new HashSet();
                                                while (data.hasNext()){
                                                    TagCouponBean couponBean=data.next();
                                                    switch (couponRequest.getCouponType()){
                                                        case UNCLAIMED:
                                                            if(couponBean.getStatus()==3){
                                                                result.add(couponBean.getEcu_Id());
                                                            }
                                                            break;
                                                        case NO_CANCEL:
                                                            if(couponBean.getStatus()==4
                                                                    &&couponBean.getEffect_End_Time().getTime()>System.currentTimeMillis()){
                                                                result.add(couponBean.getEcu_Id());
                                                            }
                                                            break;
                                                        case NO_CANCEL_EXPIRES:
                                                            if(couponBean.getStatus()==4
                                                                    &&couponBean.getEffect_End_Time().getTime()<System.currentTimeMillis()){
                                                                result.add(couponBean.getEcu_Id());
                                                            }
                                                            break;
                                                        case CANCEL:
                                                            if(couponBean.getStatus()==7){
                                                                result.add(couponBean.getEcu_Id());
                                                            }
                                                            break;
                                                        case OCCUPY:
                                                            if(couponBean.getStatus()==8){
                                                                result.add(couponBean.getEcu_Id());
                                                            }
                                                            break;
                                                        case DONATION_IN:
                                                            if(couponBean.getStatus()==9){
                                                                result.add(couponBean.getEcu_Id());
                                                            }
                                                            break;
                                                        case YET_DONATION:
                                                            if(couponBean.getStatus()==10){
                                                                result.add(couponBean.getEcu_Id());
                                                            }
                                                            break;
                                                        default:break;
                                                    }
                                                }
                                                return result.iterator();
                                            });

        return ecuRDD;
    }
}
