package com.gic.spark.filter;

import com.gic.spark.datasource.entity.DataSourceEntity;
import com.gic.spark.datasource.entity.DataSourceSharding;
import com.gic.spark.datasource.mysql.MysqlRddManager;
import com.gic.spark.entity.bean.TagCouponBean;
import com.gic.spark.entity.request.TagCouponRequest;
import com.gic.spark.entity.request.AbstractFilterRequest;
import com.gic.spark.util.AppEnvUtil;
import com.gic.spark.util.ConstantUtil;
import org.apache.spark.api.java.JavaRDD;
import scala.Tuple2;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

/**
 * @description:
 * 当前卡券数
 * @author: wangxk
 * @date: 2020/4/20
 */
public class TagCurrentCouponNumFilter implements BaseTagFilter {

    private DataSourceSharding dataSourceSharding=new DataSourceSharding(AppEnvUtil.MARKETING_SHARDING, ConstantUtil.TAB_COUPON_LOG);
    private static TagCurrentCouponNumFilter instance;
    public static TagCurrentCouponNumFilter getInstance() {
        if(null==instance){
            instance=new TagCurrentCouponNumFilter();
        }
        return instance;
    }
    private TagCurrentCouponNumFilter(){};

    @Override
    public List<DataSourceEntity> necessarySourceList() {
        List<DataSourceEntity> result = new ArrayList();
        System.out.println("dataSourceSharding==>"+dataSourceSharding);
        result.add(dataSourceSharding);
        return result;
    }

    @Override
    public JavaRDD<Long> filterValidMember(Integer enterpriseId, AbstractFilterRequest request) {
        TagCouponRequest couponRequest=(TagCouponRequest)request;
        JavaRDD<TagCouponBean> couponBeanRDD=MysqlRddManager.getPojoFromDataset(dataSourceSharding.getDatasetByEnterpriseId(enterpriseId),TagCouponBean.class).javaRDD()
                                            .filter(data->(data.getStatus()==3||data.getStatus()==4)&&data.getEffect_End_Time().getTime()>System.currentTimeMillis());


        JavaRDD<Long>ecuRDD=couponBeanRDD.mapPartitionsToPair(data->{
                                    List<Tuple2<String,Integer>>result=new ArrayList();
                                    while (data.hasNext()){
                                        TagCouponBean couponBean=data.next();
                                        switch(couponRequest.getDomainType()){
                                            case ECU_INFO:
                                                result.add(Tuple2.apply(couponBean.getEcu_Id().toString(),1));
                                                break;
                                            case ACU_INFO:
                                                if(null!=couponBean.getAcu_Id()&&couponRequest.getCuVals().contains(couponBean.getAcu_Id())){
                                                    result.add(Tuple2.apply(couponBean.getAcu_Id()+"&"+couponBean.getEcu_Id(),1));
                                                }
                                                break;
                                            case SCU_INFO:
                                                if(null!=couponBean.getAcu_Id()&&couponRequest.getCuVals().contains(couponBean.getScu_Id())){
                                                    result.add(Tuple2.apply(couponBean.getScu_Id()+"&"+couponBean.getEcu_Id(),1));
                                                }
                                                break;
                                            case MCU_INFO:
                                                if(null!=couponBean.getMcu_Id()&&couponRequest.getCuVals().contains(couponBean.getMcu_Id())){
                                                    result.add(Tuple2.apply(couponBean.getMcu_Id()+"&"+couponBean.getEcu_Id(),1));
                                                }
                                                break;
                                            default:break;
                                        }
                                    }
                                    return result.iterator();
                                }).reduceByKey((x,y)->x+y)
                                  .mapPartitions(data->{
                                      Set<Long> result=new HashSet();
                                      while (data.hasNext()){
                                          Tuple2<String,Integer>tp2=data.next();
                                          switch (couponRequest.getDomainType()){
                                              case ECU_INFO:
                                                  if(numberComputeHandle(couponRequest,tp2._2())){
                                                      result.add(Long.parseLong(tp2._1()));
                                                  }
                                                break;
                                              default:
                                                  if(numberComputeHandle(couponRequest,tp2._2())){
                                                      result.add(Long.parseLong(tp2._1().split("&")[1]));
                                                  }
                                                  break;
                                          }

                                      }
                                      return  result.iterator();
                                  });


        return ecuRDD;
    }

    public static boolean numberComputeHandle(TagCouponRequest couponRequest, int num){
        boolean result=false;
        switch (couponRequest.getNumberType()){
            case eq:
                result=num==couponRequest.getEqualNum();
                break;
            case lt:
                result=num<couponRequest.getEndNum();
                break;
            case lte:
                result=num<=couponRequest.getEndNum();
                break;
            case gt:
                result=num>couponRequest.getBeginNum();
                break;
            case gte:
                result=num>=couponRequest.getBeginNum();
                break;
            case between:
                result=num>=couponRequest.getBeginNum()&&num<=couponRequest.getEndNum();
                break;
            default:break;
        }
        return result;
    }
}
