package com.gic.spark.filter;

import com.gic.spark.datasource.entity.DataSourceEntity;
import com.gic.spark.datasource.entity.DataSourceHive;
import com.gic.spark.datasource.mysql.MysqlRddManager;
import com.gic.spark.entity.bean.TrdVirtualOrderBean;
import com.gic.spark.entity.bean.TrdVirtualOrderItemBean;
import com.gic.spark.entity.request.AbstractFilterRequest;
import com.gic.spark.entity.request.TagConsumeCommodityRequest;
import com.gic.spark.util.ConstantUtil;
import com.gic.spark.util.DateUtil;
import org.apache.commons.lang.StringUtils;
import org.apache.spark.api.java.JavaPairRDD;
import org.apache.spark.api.java.JavaRDD;
import scala.Tuple2;

import java.util.ArrayList;
import java.util.List;

/**
 * @description:
 * @author: wangxk
 * @date: 2020/8/12
 */
public class TagFirstConsumeCommodityFilter extends AbstractTagConsumRecordFilter{

    DataSourceHive dataSourceHiveOrderItem = new DataSourceHive(ConstantUtil.DWD_GIC_TRD_VIRTUAL_ORDER_ITEM_D);

    private static TagFirstConsumeCommodityFilter instance;

    public static TagFirstConsumeCommodityFilter getInstance() {
        if(null==instance){
            instance=new TagFirstConsumeCommodityFilter();
        }
        return instance;
    }

    @Override
    public List<DataSourceEntity> necessarySourceList() {
        List<DataSourceEntity> result = new ArrayList();
        result.add(dataSourceHive);
        result.add(dataSourceHiveOrderItem);
        return result;
    }

    @Override
    public JavaRDD<Long> filterValidMember(Integer enterpriseId, AbstractFilterRequest request) {
        TagConsumeCommodityRequest commodityRequest=(TagConsumeCommodityRequest)request;
        JavaRDD<TrdVirtualOrderBean>consumeRecordRDD= MysqlRddManager.getPojoFromDataset(dataSourceHive.getDatasetByEntId(enterpriseId),TrdVirtualOrderBean.class).javaRDD();

        consumeRecordRDD=statisticsTypeHandle(consumeRecordRDD,commodityRequest);
        JavaPairRDD<Long,Long>orderRdd= consumeRecordRDD.filter(data-> StringUtils.isNotEmpty(data.getReceipts_time()))
                                                            .mapToPair(data-> Tuple2.apply(data.getEcu_id(),data))
                                                            .reduceByKey((x,y)->{
                                                                if(DateUtil.strToDate(x.getReceipts_time(),DateUtil.FORMAT_DATETIME_19).getTime()
                                                                        <DateUtil.strToDate(y.getReceipts_time(),DateUtil.FORMAT_DATETIME_19).getTime()){
                                                                    return x;
                                                                }else{
                                                                    return y;
                                                                }
                                                            })
                                                            .mapToPair(data->Tuple2.apply(data._2().getVirtual_id(),data._1()));
        JavaPairRDD<Long,Long> orderItemRDD=MysqlRddManager.getPojoFromDataset(dataSourceHiveOrderItem.getDatasetByEntId(enterpriseId),TrdVirtualOrderItemBean.class).javaRDD()
                                                                .filter(data->{
                                                                    if(StringUtils.isNotEmpty(data.getSku_code())
                                                                        &&commodityRequest.getSkuCodeList().contains(data.getSku_code())){
                                                                        return true;
                                                                    }
                                                                    return false;
                                                                }).mapToPair(data->Tuple2.apply(data.getVirtual_order_id(),data.getVirtual_order_id()))
                                                                .reduceByKey((x,y)->x);


        JavaRDD<Long>ecuRdd=orderRdd.leftOuterJoin(orderItemRDD)
                                        .filter(data->data._2()._2().isPresent())
                                        .map(data->data._2()._1()).distinct();

    return ecuRdd;
    }
}
