package com.gic.spark.filter;

import com.gic.spark.datasource.entity.DataSourceEntity;
import com.gic.spark.datasource.mysql.MysqlRddManager;
import com.gic.spark.entity.bean.TrdVirtualOrderBean;
import com.gic.spark.entity.request.AbstractFilterRequest;
import com.gic.spark.entity.request.TagConsumeAmountRequest;
import com.gic.spark.util.CommonUtil;
import com.gic.spark.util.DateUtil;
import org.apache.commons.lang3.StringUtils;
import org.apache.spark.api.java.JavaRDD;
import scala.Tuple2;

import java.util.*;

/**
 * @description:
 * @author: wangxk
 * @date: 2020/8/6
 */
public class TagLowestSingleConsumptionMoneyFilter extends AbstractTagConsumRecordFilter {

    private static TagLowestSingleConsumptionMoneyFilter instance;

    public static TagLowestSingleConsumptionMoneyFilter getInstance() {
        if(null==instance){
            instance=new TagLowestSingleConsumptionMoneyFilter();
        }
        return instance;
    }

    private TagLowestSingleConsumptionMoneyFilter(){}
    @Override
    public List<DataSourceEntity> necessarySourceList() {
        List<DataSourceEntity> result = new ArrayList();
        result.add(dataSourceHive);
        return result;
    }

    @Override
    public JavaRDD<Long> filterValidMember(Integer enterpriseId, AbstractFilterRequest request) {
        TagConsumeAmountRequest consumeAmountRequest=(TagConsumeAmountRequest)request;
        JavaRDD<TrdVirtualOrderBean>consumeRecordRDD= MysqlRddManager.getPojoFromDataset(dataSourceHive.getDatasetByEntId(enterpriseId), TrdVirtualOrderBean.class).javaRDD();
        consumeRecordRDD=statisticsTypeHandle(consumeRecordRDD,consumeAmountRequest);
        int configStatus= CommonUtil.getConfigStatus(enterpriseId);

        JavaRDD<Long>ecuRdd=consumeRecordRDD.filter(data->{
                                    boolean result=false;
                                    if(StringUtils.isNotEmpty(data.getReceipts_time())){
                                        Date receiptsTime= DateUtil.strToDate(data.getReceipts_time(),DateUtil.FORMAT_DATE_10);
                                        switch (consumeAmountRequest.getTimeRangeType()){
                                            case FIXATION:
                                                if(receiptsTime.getTime()>=consumeAmountRequest.getBeginTime().getTime()
                                                        &&receiptsTime.getTime()<=consumeAmountRequest.getEndTime().getTime())
                                                    result=true;
                                                break;
                                            case LATELY:
                                                if(receiptsTime.getTime()>DateUtil.addNumForDay(new Date(),consumeAmountRequest.getTimeNum()).getTime()){
                                                    result=true;
                                                }
                                                break;
                                            default:break;
                                        }
                                    }
                                    return result;
                                }).mapToPair(data-> Tuple2.apply(data.getEcu_id(),data))
                                .groupByKey()
                                .mapPartitions(data->{
                                    List<Long>result=new ArrayList();
                                    while (data.hasNext()){

                                        Tuple2<Long, Iterable<TrdVirtualOrderBean>> tp2=data.next();
                                        double topConsumAmount=0;
                                        TrdVirtualOrderBean topConsumeAmountBean=null;
                                        Map<String,TrdVirtualOrderBean> effectiveOrderMap=new HashMap();
                                        List<TrdVirtualOrderBean>noEffectiveOrderList=new ArrayList();
                                        tp2._2().forEach(element->{
                                            if(element.getPay_amt()>0){
                                                effectiveOrderMap.put(element.getOorder_no(),element);
                                            }else{
                                                noEffectiveOrderList.add(element);
                                            }
                                        });
                                        noEffectiveOrderList.forEach(noEffectiveOrder->{
                                            TrdVirtualOrderBean effectiveOrder=effectiveOrderMap.get(noEffectiveOrder.getOorder_no());
                                            if(noEffectiveOrder.getReceipts_time().substring(0,10).equals(effectiveOrder.getReceipts_time().substring(0,10))){
                                                effectiveOrder.setPaid_amt(effectiveOrder.getPaid_amt()+noEffectiveOrder.getPaid_amt());
                                                effectiveOrder.setPay_amt(effectiveOrder.getPay_amt()+noEffectiveOrder.getPay_amt());
                                            }
                                        });
                                        for(TrdVirtualOrderBean amountBean:effectiveOrderMap.values()){
                                            topConsumAmount=configStatus==1?
                                                    (topConsumeAmountBean.getPaid_amt()<topConsumAmount?topConsumeAmountBean.getPaid_amt():topConsumAmount):
                                                    (topConsumeAmountBean.getPay_amt()<topConsumAmount?topConsumeAmountBean.getPay_amt():topConsumAmount);
                                        }


                                        switch (consumeAmountRequest.getNumberType()){
                                            case between:
                                                if(topConsumAmount>=consumeAmountRequest.getBeginNum()
                                                        &&topConsumAmount<=consumeAmountRequest.getEndNum()){
                                                    result.add(tp2._1());
                                                }
                                                break;
                                            case lt:
                                                if(topConsumAmount<consumeAmountRequest.getEndNum()){
                                                    result.add(tp2._1());
                                                }
                                                break;
                                            case gt:
                                                if(topConsumAmount>consumeAmountRequest.getBeginNum()){
                                                    result.add(tp2._1());
                                                }
                                                break;
                                            case eq:
                                                if(topConsumAmount==consumeAmountRequest.getEqualNum()){
                                                    result.add(tp2._1());
                                                }
                                                break;
                                            case lte:
                                                if(topConsumAmount<=consumeAmountRequest.getEndNum()){
                                                    result.add(tp2._1());
                                                }
                                                break;
                                            case gte:
                                                if(topConsumAmount>=consumeAmountRequest.getBeginNum()){
                                                    result.add(tp2._1());
                                                }
                                                break;
                                            default:break;
                                        }
                                    }
                                    return result.iterator();
                                });
        return ecuRdd;
    }
}
