package com.gic.spark.filter;

import com.gic.spark.datasource.entity.DataSourceEntity;
import com.gic.spark.datasource.mysql.MysqlRddManager;
import com.gic.spark.entity.bean.TrdEcuSalesLabelBean;
import com.gic.spark.entity.request.AbstractFilterRequest;
import com.gic.spark.entity.request.TagConsumeRequest;
import org.apache.spark.api.java.JavaRDD;
import scala.Tuple2;

import java.util.ArrayList;
import java.util.List;

/**
 * @description:
 * 客单价
 * @author: wangxk
 * @date: 2020/5/7
 */
public class TagPerCustomerTransactionFilter extends AbstractTagConsumFilter{

    private static TagPerCustomerTransactionFilter instance;
    public static TagPerCustomerTransactionFilter getInstance(){
        if(null==instance){
            instance=new TagPerCustomerTransactionFilter();
        }
        return instance;
    }
    private TagPerCustomerTransactionFilter(){}
    @Override
    public List<DataSourceEntity> necessarySourceList() {
        List<DataSourceEntity> result = new ArrayList();
        result.add(dataSourceHive);
        return result;
    }

    @Override
    public JavaRDD<Long> filterValidMember(Integer enterpriseId, AbstractFilterRequest request) {
        TagConsumeRequest consumeRequest=(TagConsumeRequest)request;
        JavaRDD<TrdEcuSalesLabelBean> consumeRDD= MysqlRddManager.getPojoFromDataset(dataSourceHive.getDatasetByEntId(enterpriseId), TrdEcuSalesLabelBean.class).javaRDD();
        consumeRDD=statisticsTypeHandle(consumeRDD,consumeRequest);
        JavaRDD<Long>ecuRdd=consumeRDD.mapToPair(data-> Tuple2.apply(data.getEcu_id(),data)).groupByKey()
                                          .mapPartitions(data->{
                                              List<Long> result=new ArrayList();
                                              while (data.hasNext()){
                                                Tuple2<Long,Iterable<TrdEcuSalesLabelBean>> tp2=data.next();
                                                int consumeTimes=0;
                                                double payAmt=0;
                                                for(TrdEcuSalesLabelBean consumeBean:tp2._2()){
                                                    consumeTimes+=consumeBean.getOrder_times();
                                                    payAmt+=consumeBean.getPay_amt();
                                                }
                                                  double CusSinglePiece=payAmt/consumeTimes;
                                                  switch (consumeRequest.getNumberType()){
                                                      case gt:
                                                          if(CusSinglePiece>consumeRequest.getBeginNum()){
                                                              result.add(tp2._1());
                                                          }
                                                          break;
                                                      case gte:
                                                          if(CusSinglePiece>=consumeRequest.getBeginNum()){
                                                              result.add(tp2._1());
                                                          }
                                                          break;
                                                      case lt:
                                                          if(CusSinglePiece<consumeRequest.getEndNum()){
                                                              result.add(tp2._1());
                                                          }
                                                          break;
                                                      case lte:
                                                          if(CusSinglePiece<=consumeRequest.getEndNum()){
                                                              result.add(tp2._1());
                                                          }
                                                          break;
                                                      case eq:
                                                          if(CusSinglePiece==consumeRequest.getEqualNum()){
                                                              result.add(tp2._1());
                                                          }
                                                          break;
                                                      case between:
                                                          if(CusSinglePiece>=consumeRequest.getBeginNum()
                                                                  &&CusSinglePiece<=consumeRequest.getEndNum()){
                                                              result.add(tp2._1());
                                                          }
                                                      default:break;
                                                  }
                                              }
                                              return result.iterator();
                                          });
        return ecuRdd;
    }
}
