package com.gic.spark.tag;

import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.TypeReference;
import com.gic.spark.application.SparkEnvManager;
import com.gic.spark.datasource.DataSourceManager;
import com.gic.spark.datasource.entity.DataSourceEntity;
import com.gic.spark.datasource.entity.DataSourceSharding;
import com.gic.spark.datasource.mysql.MysqlDatasource;
import com.gic.spark.datasource.mysql.MysqlRddManager;
import com.gic.spark.entity.SceneCrowdDTO;
import com.gic.spark.entity.TagConditionDTO;
import com.gic.spark.entity.TagConditionGroupDTO;
import com.gic.spark.entity.TagGroupInfo;
import com.gic.spark.entity.request.AbstractFilterRequest;
import com.gic.spark.entity.table.TabDataActuallyPaidConfig;
import com.gic.spark.entity.table.TabSceneCrowd;
import com.gic.spark.filter.*;
import com.gic.spark.util.*;
import com.google.common.base.Joiner;
import com.google.common.collect.Lists;
import org.apache.commons.lang.StringUtils;
import org.apache.spark.TaskContext;
import org.apache.spark.api.java.*;
import org.apache.spark.api.java.Optional;
import org.apache.spark.sql.Column;
import org.apache.spark.sql.Dataset;
import org.apache.spark.sql.Row;
import org.apache.spark.sql.SparkSession;
import org.elasticsearch.hadoop.cfg.ConfigurationOptions;
import org.elasticsearch.hadoop.cfg.PropertiesSettings;
import org.elasticsearch.hadoop.cfg.Settings;
import org.elasticsearch.spark.ESShardPartitioner;
import org.elasticsearch.spark.EsRddFactory;
import org.elasticsearch.spark.cfg.SparkSettings;
import org.elasticsearch.spark.cfg.SparkSettingsManager;
import org.elasticsearch.spark.rdd.EsRDDWriter;
import scala.Tuple2;
import scala.collection.JavaConversions;
import java.util.*;

import static com.gic.spark.datasource.mysql.MysqlDatasource.JDBC_OPTIONS;

/**
 * @description:
 * @author: wangxk
 * @date: 2020/4/15
 */
public class TagProcessManager {

    private List<SceneCrowdDTO>sceneCrowdDTOList=new ArrayList();
    private MysqlRddManager member4RddManager;
    private MysqlRddManager enterprise4RddManager;
    private DataSourceSharding memberSharding4Datasource;
    private boolean isProduction;
    private static TagProcessManager instance;
    public static TagProcessManager getInstance(){
        if(null==instance){
            instance=new TagProcessManager();
        }
        return instance;
    }
    private TagProcessManager(){}

    public boolean isProduction() {
        return isProduction;
    }

    public void init(boolean isProd){
        this.isProduction=isProd;
        MysqlDatasource member4Datasource = new MysqlDatasource();
        MysqlDatasource enterprise4Datasource = new MysqlDatasource();
        if(isProduction){
            member4Datasource.setJdbcUrl("jdbc:mysql://10.0.0.6:3306/gic-member4.0_2" + JDBC_OPTIONS);
            member4Datasource.setUser("cdb_outerroot");
            member4Datasource.setPassword("@09ui%sbc09");

            enterprise4Datasource.setJdbcUrl("jdbc:mysql://10.0.0.6:3306/gic-enterprise4.0" + JDBC_OPTIONS);
            enterprise4Datasource.setUser("cdb_outerroot");
            enterprise4Datasource.setPassword("@09ui%sbc09");
        }else{
            member4Datasource.setJdbcUrl("jdbc:mysql://10.0.0.6:3306/gic-member4.0_2" + JDBC_OPTIONS);
            member4Datasource.setUser("cdb_outerroot");
            member4Datasource.setPassword("@09ui%sbc09");

            enterprise4Datasource.setJdbcUrl("jdbc:mysql://10.0.0.6:3306/gic-enterprise4.0" + JDBC_OPTIONS);
            enterprise4Datasource.setUser("cdb_outerroot");
            enterprise4Datasource.setPassword("@09ui%sbc09");
        }
        member4RddManager=member4Datasource.buildRddManager();
        enterprise4RddManager=enterprise4Datasource.buildRddManager();
        memberSharding4Datasource = new DataSourceSharding(AppEnvUtil.MEMBER_SHARDING_4, ConstantUtil.TAB_ENTERPRISE_USER);

        List<TabSceneCrowd> sceneCrowdList=member4RddManager.getPojo("tab_scene_crowd", TabSceneCrowd.class,null)
                                                                .filter(new Column("delete_flag").equalTo(0))
                                                                .filter(new Column("valid_flag").equalTo(1))
                                                                .filter(new Column("real_time").equalTo(2))
                                                                .collectAsList();
        for(TabSceneCrowd sceneCrowd:sceneCrowdList){
            LinkedList<TagConditionGroupDTO>conditionGroupDTOList=JSONObject.parseObject(sceneCrowd.getTag_Condition_Group_Info(),  new TypeReference<LinkedList<TagConditionGroupDTO>>(){});
            sceneCrowdDTOList.add(new SceneCrowdDTO(sceneCrowd,conditionGroupDTOList));
        }
        List<TabDataActuallyPaidConfig>dataActuallyPaidConfigList=enterprise4RddManager.getPojo("tab_data_actually_paid_config",TabDataActuallyPaidConfig.class,null)
                                                                                            .filter(new Column("status").equalTo(1))
                                                                                            .collectAsList();
        dataActuallyPaidConfigList.forEach(data-> CommonUtil.dataActuallyPaidConfigMap.put(data.getEnterprise_Id(),data));
    }

    public void setEnterpriseId(List<Integer>enterpriseIdList){
        for(int i=sceneCrowdDTOList.size()-1;i>=0;i--){
            if(!enterpriseIdList.contains(sceneCrowdDTOList.get(i).getEnterprise_Id())){
                sceneCrowdDTOList.remove(i);
            }
        }
    }
    public void setTagGroupId(List<Integer>tagGroupIdList){
        for(int i=sceneCrowdDTOList.size()-1;i>=0;i--){
            if(!tagGroupIdList.contains(sceneCrowdDTOList.get(i).getId())){
                sceneCrowdDTOList.remove(i);
            }
        }
    }

    public void process(boolean extractData){

//        if(null!=memberDatasource){
//            System.out.println("memberDatasource==>"+memberDatasource.getHiveTableName());
//            System.out.println("memberDatasource==>"+memberDatasource.getSourceKey());
//        }

        Map<Integer, List<TagProcessEntity>> tagGroupByEnterpriseMap = new HashMap<>();
        Map<Long, BaseTagFilter> tagIdToFilterMap = new HashMap();

        for(SceneCrowdDTO sceneCrowdDTO:sceneCrowdDTOList){
            if(sceneCrowdDTO.getReal_Time()==2){
                LinkedList<TagConditionGroupDTO> conditionGroupDTOS=sceneCrowdDTO.getConditionGroupDTOList();
                for(int i=0;i<conditionGroupDTOS.size();i++){

                    TagProcessEntity entity=new TagProcessEntity();
                    entity.enterpriseId=sceneCrowdDTO.getEnterprise_Id();
                    entity.tagGroupId=sceneCrowdDTO.getId();
                    entity.level=i+1;

                    entity.tagList=conditionGroupDTOS.get(i).getConditionInfos();
                    for(TagConditionDTO conditionDTO:entity.tagList){//将tag同filter进行映射
                        BaseTagFilter tagFilter=TagFilterFactory.getInstance().getTagFilter(conditionDTO);

                        if(null!=tagFilter){
                            tagIdToFilterMap.put(conditionDTO.getTagId(),tagFilter);
                            for(DataSourceEntity sourceEntity:tagFilter.necessarySourceList()){
                                System.out.println("enterprise_id==>"+entity.enterpriseId);
                                if(null!=sourceEntity){
                                    System.out.println("tagEsFieldName==>"+conditionDTO.getTagEsFieldName());
//                                    System.out.println("SourceKey==>"+sourceEntity.getSourceKey());
//                                    System.out.println("HiveTableName==>"+sourceEntity.getHiveTableName());
                                }else{
                                    System.out.println("tagEsFieldName==>"+conditionDTO.getTagEsFieldName()+" ,sourceEntity==>"+sourceEntity);
                                }
                            }
                        }
                    }

                    if(!tagGroupByEnterpriseMap.containsKey(sceneCrowdDTO.getEnterprise_Id())){
                        tagGroupByEnterpriseMap.put(sceneCrowdDTO.getEnterprise_Id(),new ArrayList());
                    }
                    tagGroupByEnterpriseMap.get(sceneCrowdDTO.getEnterprise_Id()).add(entity);
                }
            }
        }

        //准备标签需要的数据
        for (Map.Entry<Integer, List<TagProcessEntity>> enterpriseTagEntry : tagGroupByEnterpriseMap.entrySet()) {
            for (TagProcessEntity processEntity : enterpriseTagEntry.getValue()) {
                for (TagConditionDTO conditionDTO : processEntity.tagList) {
                    if (tagIdToFilterMap.containsKey(conditionDTO.getTagId())) {
                        for (DataSourceEntity sourceEntity : tagIdToFilterMap.get(conditionDTO.getTagId()).necessarySourceList()) {
//                            System.out.println("enterpriseId==>"+enterpriseTagEntry.getKey());
//                            System.out.println("SourceKey==>"+sourceEntity.getSourceKey());
//                            System.out.println("HiveTableName==>"+sourceEntity.getHiveTableName());
                            DataSourceManager.getInstance().addSourceEntity(sourceEntity, enterpriseTagEntry.getKey().intValue());
                        }
                    }
                }
            }
            DataSourceManager.getInstance().addSourceEntity(memberSharding4Datasource,enterpriseTagEntry.getKey().intValue());
        }

        if (extractData) {
            DataSourceManager.getInstance().init(isProduction);
            DataSourceManager.getInstance().extractDataToDatabase();
            DingtalkMessageUtil.sendAlertMessage("extractData to hive finish !");
        }

        //处理标签数据
        for (Map.Entry<Integer, List<TagProcessEntity>> enterpriseTagEntry : tagGroupByEnterpriseMap.entrySet()) {
            Integer enterpriseId=enterpriseTagEntry.getKey();
            List<JavaPairRDD<Long, String>> filterRddList = new ArrayList();
            for(TagProcessEntity entity:enterpriseTagEntry.getValue()){
                for(TagConditionDTO conditionDTO:entity.tagList){
                    if(tagIdToFilterMap.containsKey(conditionDTO.getTagId())){
                        BaseTagFilter tagFilter=tagIdToFilterMap.get(conditionDTO.getTagId());
                        AbstractFilterRequest filterRequest=TagValueParser.parseFilterValue(conditionDTO,enterpriseId);

                        final String groupId = entity.tagGroupId + "_" + conditionDTO.getTagId() + "_" + entity.level;

                        JavaPairRDD<Long, String> rdd = tagFilter.filterValidMember(enterpriseId,filterRequest).mapToPair(data-> Tuple2.apply(data,groupId));
                        filterRddList.add(rdd);
                    }
                }
            }

            if(filterRddList.size()>0){
                JavaPairRDD<Long,String>memberGroupRdd=null;
                for(JavaPairRDD<Long,String>rdd:filterRddList){
                    if(null==memberGroupRdd){
                        memberGroupRdd=rdd;
                    }else{
                        memberGroupRdd=memberGroupRdd.union(rdd);
                    }
                }
                JavaPairRDD<Long,Long>userRdd=memberSharding4Datasource.getDatasetByEnterpriseId(enterpriseId).select("id").javaRDD()
                                            .mapToPair(data->Tuple2.apply((Long)data.getAs("id"),(Long)data.getAs("id")))
                                            .reduceByKey((x,y)->x);

                JavaPairRDD<Long,String>updateMemberGroupRdd=userRdd.leftOuterJoin(memberGroupRdd.groupByKey())
                                                                            .mapPartitionsToPair(data->{
                                                                                List<Tuple2<Long,String>> result=new ArrayList();
                                                                                while (data.hasNext()){
                                                                                    Tuple2<Long, Optional<Iterable<String>>> tp2=data.next()._2();
                                                                                    Long id=tp2._1();
                                                                                    String groupId=tp2._2().isPresent()? Joiner.on(" ").join(Lists.newArrayList(tp2._2().get())):"";
                                                                                    JSONObject json = new JSONObject();
                                                                                    json.put("id",id);
                                                                                    json.put("sceneTags_b",groupId);
                                                                                    result.add(Tuple2.apply(id,json.toString()));
                                                                                }
                                                                                return result.iterator();
                                                                            });

                JavaPairRDD<Long,String>cacheMemberGroupRdd=updateMemberGroupRdd.cache();

                updateIndex(cacheMemberGroupRdd,enterpriseId);

                saveToHive(cacheMemberGroupRdd,enterpriseId);

                cacheMemberGroupRdd.unpersist();
            }
        }


    }

    private void saveToHive(JavaPairRDD<Long, String> updateMemberGroup,Integer enterpriseId){
        JavaRDD<TagGroupInfo> tagGroupInfoRDD=updateMemberGroup.mapPartitions(data->{
                                                List<TagGroupInfo>tagGroupInfoList=new ArrayList();
                                                while(data.hasNext()){
                                                    Tuple2<Long,String>tp2=data.next();
                                                    JSONObject json = JSONObject.parseObject(tp2._2());
                                                    if(StringUtils.isNotEmpty(json.getString("sceneTags_b"))){
                                                        tagGroupInfoList.add(new TagGroupInfo(json.getLong("id"),enterpriseId,json.getString("sceneTags_b")));
                                                    }
                                                }
                                                return tagGroupInfoList.iterator();
                                            });
        SparkSession sparkSession=SparkEnvManager.getInstance().getSparkSession();
        Dataset<Row>tagGroupInfoDataset=sparkSession.createDataFrame(tagGroupInfoRDD,TagGroupInfo.class);
        tagGroupInfoDataset.createOrReplaceTempView("tag_group_info_tmp");

        tagGroupInfoDataset.show();
//        sparkSession.sql(String.format("INSERT overwrite table %s.tag_group_info PARTITION(enterprise_id = '%s') SELECT id,tag_group_info from tag_group_info_tmp",isProduction?"tag4_prod":"tag4_test", enterpriseId));

    }

    private void updateIndex(JavaPairRDD<Long, String> updateMemberGroup, Integer enterpriseId) {

        Map<String, String> conf = new HashMap();
        String indexName = EsRequestUtil.getESIindexName(enterpriseId);
        System.out.println("indexName===>" + indexName);
        conf.put("es.resource", indexName + "/mapper_type");
        conf.put("es.nodes", AppEnvUtil.ES_NODES);
        conf.put("es.mapping.date.rich", "false");
        conf.put("es.index.auto.create", "true");
        conf.put("es.mapping.id", "id");
        conf.put("es.write.operation", "upsert");
        conf.put("es.batch.size.bytes", "1024k");
        conf.put("es.batch.size.entries", "1500");
        conf.put(ConfigurationOptions.ES_INPUT_JSON, "true");

        SparkSettings sparkCfg = new SparkSettingsManager().load(SparkEnvManager.getInstance().getSparkContext().getConf());
        Settings cfg = new PropertiesSettings().load(sparkCfg.save());
        cfg.merge(conf);
        String settings = cfg.save();

        ESShardPartitioner partitioner = new ESShardPartitioner(settings);

        updateMemberGroup.partitionBy(partitioner).map(data ->data._2()).foreachPartition(data -> {
            Settings newSettings = new PropertiesSettings().load(settings);
            EsRDDWriter<String> writer = EsRddFactory.createJsonWriter(newSettings.save(), false);
            writer.write(TaskContext.get(), JavaConversions.asScalaIterator(data));
        });
    }

}
