package com.gic.spark.tag;

import com.alibaba.fastjson.JSONObject;
import com.gic.spark.entity.TagConditionDTO;
import com.gic.spark.entity.TagConditionValDTO;
import com.gic.spark.entity.enumtype.*;
import com.gic.spark.entity.request.*;
import com.gic.spark.util.DateUtil;
import com.gic.spark.util.IndexRequestUtil;
import org.apache.commons.lang3.StringUtils;

import java.sql.Timestamp;
import java.util.*;
import java.util.regex.Pattern;

import static com.gic.spark.entity.enumtype.TagValKeyEnum.COMPONENT_STORE;

/**
 * @description:
 * @author: wangxk
 * @date: 2020/4/15
 */
public class TagValueParser {

    public static AbstractFilterRequest parseFilterValue(TagConditionDTO conditionDTO,Integer enterpriseId){
        AbstractFilterRequest request=null;
        switch (conditionDTO.getTagEsFieldName()){
            //积分
            case TagConstant.TAG_CODE_ACCUMULATED_INTEGRAL:
                request=getIntegralRequest(conditionDTO.getTagTemplateElInfo());
                break;
            case TagConstant.TAG_CODE_ABOUT_EXPIRE_INTEGRAL:
                request=getIntegralRequest(conditionDTO.getTagTemplateElInfo());
                break;

            //卡卷
            case TagConstant.TAG_CODE_CURRENT_COUPON_NUM:
                request=getCurrentCouponNumRequest(conditionDTO.getTagTemplateElInfo());
                break;
            case TagConstant.TAG_CODE_UNCLAIMED_COUPON:
                request=getCouponRequest(conditionDTO);
                break;
            case TagConstant.TAG_CODE_GET_NO_CANCEL_COUPON:
                request=getCouponRequest(conditionDTO);
                break;
            case TagConstant.TAG_CODE_NO_CANCEL_EXPIRES_COUPON:
                request=getCouponRequest(conditionDTO);
                break;
            case TagConstant.TAG_CODE_CANCEL_COUPON:
                request=getCouponRequest(conditionDTO);
                break;
            case TagConstant.TAG_CODE_OCCUPY_COUPON:
                request=getCouponRequest(conditionDTO);
                break;
            case TagConstant.TAG_CODE_DONATION_IN_COUPON:
                request=getCouponRequest(conditionDTO);
                break;
            case TagConstant.TAG_CODE_YET_DONATION_COUPON:
                request=getCouponRequest(conditionDTO);
                break;

            //消费统计
            case TagConstant.TAG_CODE_CONSUMPTION_TIME:
                request=getConsumeRequest(conditionDTO.getTagTemplateElInfo());
                break;
            case TagConstant.TAG_CODE_PER_CUSTOMER_TRANSACTION:
                request=getConsumeRequest(conditionDTO.getTagTemplateElInfo());
                break;
            case TagConstant.TAG_CODE_ASSOCIATED_PURCHASE_RATE:
                request=getConsumeRequest(conditionDTO.getTagTemplateElInfo());
                break;
            case TagConstant.TAG_CODE_AVERAGE_DISCOUNT_FACTOR:
                request=getConsumeRequest(conditionDTO.getTagTemplateElInfo());
                break;
            case TagConstant.TAG_CODE_CONSUMPTION_SLEEP_DAYS:
                request=getConsumeRequest(conditionDTO.getTagTemplateElInfo());
                break;

            //消费金额记录
            case TagConstant.TAG_CODE_CONSUME_TOTAL:
                request=getConsumeAmountRequest(conditionDTO.getTagTemplateElInfo());
                break;
            case TagConstant.TAG_CODE_HISTORY_CONSUME_TOTAL:
                request=getConsumeAmountRequest(conditionDTO.getTagTemplateElInfo());
                break;
            case TagConstant.TAG_CODE_FIRST_CONSUMPTION_MONEY:
                request=getConsumeAmountRequest(conditionDTO.getTagTemplateElInfo());
                break;
            case TagConstant.TAG_CODE_LATELY_CONSUMPTION_MONEY:
                request=getConsumeAmountRequest(conditionDTO.getTagTemplateElInfo());
                break;
            case TagConstant.TAG_CODE_TOP_SINGLE_CONSUMPTION_MONEY:
                request=getConsumeAmountRequest(conditionDTO.getTagTemplateElInfo());
                break;
            case TagConstant.TAG_CODE_LOWEST_SINGLE_CONSUMPTION_MONEY:
                request=getConsumeAmountRequest(conditionDTO.getTagTemplateElInfo());
                break;

            //消费时间
            case TagConstant.TAG_CODE_FIRST_CONSUME_TIME:
                request=getConsumeTimeRequest(conditionDTO.getTagTemplateElInfo());
                break;
//            case TagConstant.TAG_CODE_HISTORY_CONSUME_TIME:
//                request=getConsumeTimeRequest(conditionDTO.getTagTemplateElInfo());
//                break;
            case TagConstant.TAG_CODE_LATELY_CONSUME_TIME:
                request=getConsumeTimeRequest(conditionDTO.getTagTemplateElInfo());
                break;
            case TagConstant.TAG_CODE_CONSUME_TIME:
                request=getConsumeTimeRequest(conditionDTO.getTagTemplateElInfo());
                break;
            case TagConstant.TAG_CODE_CONSUME_SLEEP_DAY:
//                request=
                break;

            //消费渠道
            case TagConstant.TAG_CODE_FIRST_CONSUMPTION_CHANNEL:
                request=getConsumeChannelRequest(conditionDTO.getTagTemplateElInfo());
                break;
            case TagConstant.TAG_CODE_LATELY_CONSUMPTION_CHANNEL:
                request=getConsumeChannelRequest(conditionDTO.getTagTemplateElInfo());
                break;
            //线下消费门店
            case TagConstant.TAG_CODE_FIRST_OFFLINE_CONSUMPTION_STORE:
                request=getOfflineConsumeStoreRequest(conditionDTO.getTagTemplateElInfo(),enterpriseId);
                break;
            case TagConstant.TAG_CODE_RECENTLY_OFFLINE_CONSUMPTION_STORE:
                request=getOfflineConsumeStoreRequest(conditionDTO.getTagTemplateElInfo(),enterpriseId);
                break;
            case TagConstant.TAG_CODE_HISTORY_OFFLINE_CONSUMPTION_STORE:
                request=getOfflineConsumeStoreRequest(conditionDTO.getTagTemplateElInfo(),enterpriseId);
                break;
            case TagConstant.TAG_CODE_OFFLINE_CONSUMPTION_STORE:
                request=getOfflineConsumeStoreRequest(conditionDTO.getTagTemplateElInfo(),enterpriseId);
                break;

            //线上消费店铺
            case TagConstant.TAG_CODE_FIRST_ONLINE_CONSUMPTION_STORE:
                request=getOnlineConsumeStoreRequest(conditionDTO.getTagTemplateElInfo(),enterpriseId);
                break;
            case TagConstant.TAG_CODE_LATELY_ONLINE_CONSUMPTION_STORE:
                request=getOnlineConsumeStoreRequest(conditionDTO.getTagTemplateElInfo(),enterpriseId);
                break;
            case TagConstant.TAG_CODE_HISTORY_ONLINE_CONSUMPTION_STORE:
                request=getOnlineConsumeStoreRequest(conditionDTO.getTagTemplateElInfo(),enterpriseId);
                break;
            case TagConstant.TAG_CODE_ONLINE_CONSUMPTION_STORE:
                request=getOnlineConsumeStoreRequest(conditionDTO.getTagTemplateElInfo(),enterpriseId);
                break;

            //消费商品
            case TagConstant.TAG_CODE_FIRST_CONSUME_COMMODITY:
                request=getConsumeCommodityRequest(conditionDTO.getTagTemplateElInfo());
                break;
            case TagConstant.TAG_CODE_LATELY_CONSUME_COMMODITY:
                request=getConsumeCommodityRequest(conditionDTO.getTagTemplateElInfo());
                break;
            case TagConstant.TAG_CODE_HISTORY_CONSUME_COMMODITY:
                request=getConsumeCommodityRequest(conditionDTO.getTagTemplateElInfo());
                break;
            case TagConstant.TAG_CODE_CONSUME_COMMODITY:
                request=getConsumeCommodityRequest(conditionDTO.getTagTemplateElInfo());
                break;
            default:break;
        }
        return request;
    }

    private static AbstractFilterRequest getConsumeCommodityRequest(List<TagConditionValDTO> conditionValDTOList) {
        TagConsumeCommodityRequest request=new TagConsumeCommodityRequest();
        for (TagConditionValDTO conditionValDTO : conditionValDTOList) {
            if (Pattern.compile("flag").matcher(conditionValDTO.getKey()).find()) {
                setStatisticsTypeHandle(request, conditionValDTO.getKey(), conditionValDTO.getVal());
            }else if(conditionValDTO.getKey().equals(TagValKeyEnum.COMPONENT_COMMODITY.getKey())){
                List<String>skuCodeList=null;//需要调用接口
                request.setSkuCodeList(skuCodeList);
            }else if(Pattern.compile("timeRange").matcher(conditionValDTO.getKey()).find()){
                String[] keys=conditionValDTO.getKey().split("\\.");
                switch (keys[1]) {
                    case TagConstant.TAG_TIME_TYPE_FIXATION:
                        String[] vals = conditionValDTO.getVal().split(",");
                        request.setBeginTime(DateUtil.stringToDate(vals[0]));
                        request.setEndTime(DateUtil.stringToDate(vals[1]));
                        request.setTimeRangeType(TimeRangeType.FIXATION);
                        break;
                    case TagConstant.TAG_TIME_TYPE_LATELY:
                        request.setTimeNum(Integer.parseInt(conditionValDTO.getVal()));
                        request.setTimeRangeType(TimeRangeType.LATELY);
                        request.setYearMonthDayType(YearMonthDayType.DAY);
                        break;
                    case TagConstant.TAG_TIME_TYPE_LATER:
                        request.setTimeNum(Integer.parseInt(conditionValDTO.getVal()));
                        request.setTimeRangeType(TimeRangeType.LATER);
                        request.setYearMonthDayType(YearMonthDayType.DAY);
                        break;
                    default:
                        break;
                }
            }
        }
        return request;
    }

    private static AbstractFilterRequest getOnlineConsumeStoreRequest(List<TagConditionValDTO> conditionValDTOList,Integer enterpriseId) {
        TagConsumeStoreRequest request=new TagConsumeStoreRequest();
        for (TagConditionValDTO conditionValDTO : conditionValDTOList) {
            if (Pattern.compile("flag").matcher(conditionValDTO.getKey()).find()) {
                setStatisticsTypeHandle(request, conditionValDTO.getKey(), conditionValDTO.getVal());
            } else if(conditionValDTO.getKey().equals(TagValKeyEnum.COMPONENT_STORE.getKey())){
                String val=conditionValDTO.getVal();
                List<String>storeList = IndexRequestUtil.getStoreId(enterpriseId, val, TagProcessManager.getInstance().isProduction());
                request.setStoreList(storeList);
            }else if(Pattern.compile("timeRange").matcher(conditionValDTO.getKey()).find()){
                String[] keys=conditionValDTO.getKey().split("\\.");
                switch (keys[1]){
                    case TagConstant.TAG_TIME_TYPE_FIXATION:
                        String[] vals=conditionValDTO.getVal().split(",");
                        request.setBeginTime(DateUtil.stringToDate(vals[0]));
                        request.setEndTime(DateUtil.stringToDate(vals[1]));
                        request.setTimeRangeType(TimeRangeType.FIXATION);
                        break;
                    case TagConstant.TAG_TIME_TYPE_LATELY:
                        request.setTimeNum(Integer.parseInt(conditionValDTO.getVal()));
                        request.setTimeRangeType(TimeRangeType.LATELY);
                        request.setYearMonthDayType(YearMonthDayType.DAY);
                        break;
                    case TagConstant.TAG_TIME_TYPE_LATER:
                        request.setTimeNum(Integer.parseInt(conditionValDTO.getVal()));
                        request.setTimeRangeType(TimeRangeType.LATER);
                        request.setYearMonthDayType(YearMonthDayType.DAY);
                        break;
                    default:break;
                }
            }
        }
        return request;
    }

    private static AbstractFilterRequest getOfflineConsumeStoreRequest(List<TagConditionValDTO> conditionValDTOList,Integer enterpriseId) {
        TagConsumeStoreRequest request=new TagConsumeStoreRequest();
        for (TagConditionValDTO conditionValDTO : conditionValDTOList) {
            if (Pattern.compile("flag").matcher(conditionValDTO.getKey()).find()) {
                setStatisticsTypeHandle(request, conditionValDTO.getKey(), conditionValDTO.getVal());
            } else if(conditionValDTO.getKey().equals(TagValKeyEnum.COMPONENT_STORE.getKey())){
                String val=conditionValDTO.getVal();
                List<String>storeList= IndexRequestUtil.getStoreId(enterpriseId,val,TagProcessManager.getInstance().isProduction()) ;//需要调用接口
                request.setStoreList(storeList);
            }else if(Pattern.compile("timeRange").matcher(conditionValDTO.getKey()).find()){
                String[] keys=conditionValDTO.getKey().split("\\.");
                switch (keys[1]){
                    case TagConstant.TAG_TIME_TYPE_FIXATION:
                        String[] vals=conditionValDTO.getVal().split(",");
                        request.setBeginTime(DateUtil.stringToDate(vals[0]));
                        request.setEndTime(DateUtil.stringToDate(vals[1]));
                        request.setTimeRangeType(TimeRangeType.FIXATION);
                        break;
                    case TagConstant.TAG_TIME_TYPE_LATELY:
                        request.setTimeNum(Integer.parseInt(conditionValDTO.getVal()));
                        request.setTimeRangeType(TimeRangeType.LATELY);
                        request.setYearMonthDayType(YearMonthDayType.DAY);
                        break;
                    case TagConstant.TAG_TIME_TYPE_LATER:
                        request.setTimeNum(Integer.parseInt(conditionValDTO.getVal()));
                        request.setTimeRangeType(TimeRangeType.LATER);
                        request.setYearMonthDayType(YearMonthDayType.DAY);
                        break;
                    default:break;
                }
            }
        }
        return request;
    }

    private static AbstractFilterRequest getConsumeChannelRequest(List<TagConditionValDTO> conditionValDTOList) {
        TagConsumeChannelRequest request = new TagConsumeChannelRequest();
        for (TagConditionValDTO conditionValDTO : conditionValDTOList) {
            if (Pattern.compile("flag").matcher(conditionValDTO.getKey()).find()) {
                setStatisticsTypeHandle(request, conditionValDTO.getKey(), conditionValDTO.getVal());
            } else {
                String[] vals=conditionValDTO.getVal().split(",");
                request.setChannelVals(Arrays.asList(vals));
            }
        }
        return request;
    }

    private static AbstractFilterRequest getConsumeTimeRequest(List<TagConditionValDTO> conditionValDTOList) {
        TagConsumeTimeRequest request=new TagConsumeTimeRequest();
        for(TagConditionValDTO conditionValDTO:conditionValDTOList) {
            if(Pattern.compile("flag").matcher(conditionValDTO.getKey()).find()){
                setStatisticsTypeHandle(request,conditionValDTO.getKey(),conditionValDTO.getVal());
            }else {
                setTimeValueHandle(request,conditionValDTO.getKey(),conditionValDTO.getVal());
            }
        }
        return request;
    }

    private static AbstractFilterRequest getConsumeAmountRequest(List<TagConditionValDTO> conditionValDTOList) {
        TagConsumeAmountRequest request=new TagConsumeAmountRequest();
        for(TagConditionValDTO conditionValDTO:conditionValDTOList){
            System.out.println("key==>"+conditionValDTO.getKey());
            if(Pattern.compile("flag").matcher(conditionValDTO.getKey()).find()){
                setStatisticsTypeHandle(request,conditionValDTO.getKey(),conditionValDTO.getVal());
            }else{
                String[] keys=conditionValDTO.getKey().split("\\.");
                switch (keys[0]){
                    case TagConstant.TAG_KEY_TYPE_TIME_RANGE:
                        switch (keys[1]){
                            case TagConstant.TAG_TIME_TYPE_FIXATION:
                                String[] vals=conditionValDTO.getVal().split(",");
                                request.setBeginTime(DateUtil.stringToDate(vals[0]));
                                request.setEndTime(DateUtil.stringToDate(vals[1]));
                                request.setTimeRangeType(TimeRangeType.FIXATION);
                                break;
                            case TagConstant.TAG_TIME_TYPE_LATELY:
                                request.setTimeNum(Integer.parseInt(conditionValDTO.getVal()));
                                request.setTimeRangeType(TimeRangeType.LATELY);
                                request.setYearMonthDayType(YearMonthDayType.DAY);
                                break;
                            case TagConstant.TAG_TIME_TYPE_LATER:
                                request.setTimeNum(Integer.parseInt(conditionValDTO.getVal()));
                                request.setTimeRangeType(TimeRangeType.LATER);
                                request.setYearMonthDayType(YearMonthDayType.DAY);
                                break;
                            default:break;
                        }
                        break;
                    case  TagConstant.TAG_KEY_TYPE_NUMBER:
                        setDoubleValueHandle(request,keys[1],conditionValDTO.getVal());
                    default:break;
                }
            }
        }
        return request;
    }

    private static AbstractFilterRequest getConsumeRequest(List<TagConditionValDTO> conditionValDTOList) {
        TagConsumeRequest request=new TagConsumeRequest();
        for(TagConditionValDTO conditionValDTO:conditionValDTOList){

            if(Pattern.compile("flag").matcher(conditionValDTO.getKey()).find()){
                setStatisticsTypeHandle(request,conditionValDTO.getKey(),conditionValDTO.getVal());
            }else{
                String[] keys=conditionValDTO.getKey().split("\\.");
                switch (keys[0]){
                    case TagConstant.TAG_KEY_TYPE_NUMBER:
                        setIntegerValueHandle(request,keys[1],conditionValDTO.getVal());
                        break;
                    default:break;
                }
            }

        }
        return request;
    }

    private static AbstractFilterRequest getCouponRequest(TagConditionDTO conditionDTO) {
        TagCouponRequest request=new TagCouponRequest();
        for(TagConditionValDTO conditionValDTO:conditionDTO.getTagTemplateElInfo()){
            switch (conditionValDTO.getKey()){
                case TagConstant.TAG_COMPONENT_COUPON:
                    switch (conditionDTO.getTagEsFieldName()){
                        case TagConstant.TAG_CODE_UNCLAIMED_COUPON:
                            request.setCouponType(CouponType.UNCLAIMED);
                            break;
                        case TagConstant.TAG_CODE_GET_NO_CANCEL_COUPON:
                            request.setCouponType(CouponType.NO_CANCEL);
                            break;
                        case TagConstant.TAG_CODE_NO_CANCEL_EXPIRES_COUPON:
                            request.setCouponType(CouponType.NO_CANCEL_EXPIRES);
                            break;
                        case TagConstant.TAG_CODE_CANCEL_COUPON:
                            request.setCouponType(CouponType.CANCEL);
                            break;
                        case TagConstant.TAG_CODE_OCCUPY_COUPON:
                            request.setCouponType(CouponType.OCCUPY);
                            break;
                        case TagConstant.TAG_CODE_DONATION_IN_COUPON:
                            request.setCouponType(CouponType.DONATION_IN);
                            break;
                        case TagConstant.TAG_CODE_YET_DONATION_COUPON:
                            request.setCouponType(CouponType.YET_DONATION);
                            break;
                        default:break;
                    }
                    List<Integer>couponList=new ArrayList();
                    if(StringUtils.isNotEmpty(conditionValDTO.getVal())){
                        String[] couponIds= conditionValDTO.getVal().split(",");
                        for (String couponId : couponIds) {
                            couponList.add(Integer.valueOf(couponId));
                        }
                    }
                    request.setCouponList(couponList);
                    break;
                default:break;
            }
        }
        return request;
    }

    private static AbstractFilterRequest getCurrentCouponNumRequest(List<TagConditionValDTO> conditionValDTOList) {
        TagCouponRequest request=new TagCouponRequest();
        for(TagConditionValDTO conditionValDTO:conditionValDTOList){
            String[] keys=conditionValDTO.getKey().split("\\.");
            if(keys.length==3){
                setDomainHandle(request,keys[1],conditionValDTO.getVal());
            }else{
                switch (keys[0]){
                    case TagConstant.TAG_KEY_TYPE_NUMBER:
                        setIntegerValueHandle(request,keys[1],conditionValDTO.getVal());
                        break;
                    default:break;
                }
            }
        }
        return request;
    }

    private static AbstractFilterRequest getIntegralRequest(List<TagConditionValDTO> conditionValDTOList) {
        TagIntegralRequest request=new TagIntegralRequest();
        for(TagConditionValDTO conditionValDTO:conditionValDTOList){
            String[] keys=conditionValDTO.getKey().split("\\.");
            if(keys.length==1){
                setDomainHandle(request,keys[0],conditionValDTO.getVal());
            }else{
                switch (keys[0]){
                    case TagConstant.TAG_KEY_TYPE_TIME_RANGE:
                        switch (keys[1]){
                            case TagConstant.TAG_TIME_TYPE_FIXATION:
                                String[] vals=conditionValDTO.getVal().split(",");
                                request.setBeginTime(new Timestamp(DateUtil.stringToDate(vals[0]).getTime()));
                                request.setEndTime(new Timestamp(DateUtil.stringToDate(vals[1]).getTime()));
                                request.setTimeRangeType(TimeRangeType.FIXATION);
                                break;
                            case TagConstant.TAG_TIME_TYPE_LATELY:
                                request.setTimeNum(Integer.parseInt(conditionValDTO.getVal()));
                                request.setTimeRangeType(TimeRangeType.LATELY);
                                break;
                            case TagConstant.TAG_TIME_TYPE_LATER:
                                request.setTimeNum(Integer.parseInt(conditionValDTO.getVal()));
                                request.setTimeRangeType(TimeRangeType.LATER);
                                break;
                            default:break;
                        }
                        break;
                    case  TagConstant.TAG_KEY_TYPE_NUMBER:
                        setIntegerValueHandle(request,keys[1],conditionValDTO.getVal());
                    default:break;
                }
            }
        }
        return request;
    }

    private static void setTimeValueHandle(AbstractFilterRequestTime request,String key,String val){

        if(key.equals(TagValKeyEnum.CALENDAR_YMD.getKey())){
            String[] vals=val.split(",");
            request.setBeginTime(DateUtil.stringToDate(vals[0]));
            request.setEndTime(DateUtil.stringToDate(vals[1]));
            request.setTimeRangeType(TimeRangeType.FIXATION);
        }else if(key.equals(TagValKeyEnum.CALENDAR_YMD_DAY_TODAY.getKey())){
            request.setYearMonthDayType(YearMonthDayType.DAY);
            request.setTimeRangeType(TimeRangeType.CURRENT);
        }else if(key.equals(TagValKeyEnum.CALENDAR_YMD_MOD_TODAY.getKey())){
            request.setYearMonthDayType(YearMonthDayType.MONTH);
            request.setTimeRangeType(TimeRangeType.CURRENT);
        }else if(key.equals(TagValKeyEnum.CALENDAR_YMD_YEAR_TODAY.getKey())){
            request.setYearMonthDayType(YearMonthDayType.YEAR);
            request.setTimeRangeType(TimeRangeType.CURRENT);
        }else if(key.equals(TagValKeyEnum.CALENDAR_YMD_DAY_LATER.getKey())){
            request.setTimeNum(Integer.parseInt(val));
            request.setYearMonthDayType(YearMonthDayType.DAY);
            request.setTimeRangeType(TimeRangeType.LATER);
        }else if(key.equals(TagValKeyEnum.CALENDAR_YMD_MOD_LATER.getKey())){
            request.setTimeNum(Integer.parseInt(val));
            request.setYearMonthDayType(YearMonthDayType.MONTH);
            request.setTimeRangeType(TimeRangeType.LATER);
        }else if(key.equals(TagValKeyEnum.CALENDAR_YMD_YEAR_LATER.getKey())){
            request.setTimeNum(Integer.parseInt(val));
            request.setYearMonthDayType(YearMonthDayType.YEAR);
            request.setTimeRangeType(TimeRangeType.LATER);
        }else if(key.equals(TagValKeyEnum.CALENDAR_YMD_DAY_LATELY.getKey())){
            request.setTimeNum(Integer.parseInt(val));
            request.setYearMonthDayType(YearMonthDayType.DAY);
            request.setTimeRangeType(TimeRangeType.LATELY);
        }else if(key.equals(TagValKeyEnum.CALENDAR_YMD_MOD_LATELY.getKey())){
            request.setTimeNum(Integer.parseInt(val));
            request.setYearMonthDayType(YearMonthDayType.MONTH);
            request.setTimeRangeType(TimeRangeType.LATELY);
        }else if(key.equals(TagValKeyEnum.CALENDAR_YMD_YEAR_LATELY.getKey())){
            request.setTimeNum(Integer.parseInt(val));
            request.setYearMonthDayType(YearMonthDayType.YEAR);
            request.setTimeRangeType(TimeRangeType.LATELY);
        }
    }

    private static void setDoubleValueHandle(AbstractFilterRequestDouble request,String key, String val){
        switch (key){
            case TagConstant.TAG_COMPUTE_TYPE_GT:
                request.setBeginNum(Double.parseDouble(val));
                request.setNumberType(NumberType.gt);
                break;
            case TagConstant.TAG_COMPUTE_TYPE_GTE:
                request.setBeginNum(Double.parseDouble(val));
                request.setNumberType(NumberType.gte);
                break;
            case TagConstant.TAG_COMPUTE_TYPE_LT:
                request.setEndNum(Double.parseDouble(val));
                request.setNumberType(NumberType.lt);
                break;
            case TagConstant.TAG_COMPUTE_TYPE_LTE:
                request.setEndNum(Double.parseDouble(val));
                request.setNumberType(NumberType.lte);
                break;
            case TagConstant.TAG_COMPUTE_TYPE_EQ:
                request.setEqualNum(Double.parseDouble(val));
                request.setNumberType(NumberType.eq);
                break;
            case TagConstant.TAG_COMPUTE_TYPE_BETWEEN:
                String[] vals=val.split(",");
                request.setBeginNum(Double.parseDouble(vals[0]));
                request.setEndNum(Double.parseDouble(vals[1]));
                request.setNumberType(NumberType.between);
                break;
            default:break;
        }
    }

    private static void setIntegerValueHandle(AbstractFilterRequestInteger request,String key, String val){
        switch (key){
            case TagConstant.TAG_COMPUTE_TYPE_GT:
                request.setBeginNum(Integer.parseInt(val));
                request.setNumberType(NumberType.gt);
                break;
            case TagConstant.TAG_COMPUTE_TYPE_GTE:
                request.setBeginNum(Integer.parseInt(val));
                request.setNumberType(NumberType.gte);
                break;
            case TagConstant.TAG_COMPUTE_TYPE_LT:
                request.setEndNum(Integer.parseInt(val));
                request.setNumberType(NumberType.lt);
                break;
            case TagConstant.TAG_COMPUTE_TYPE_LTE:
                request.setEndNum(Integer.parseInt(val));
                request.setNumberType(NumberType.lte);
                break;
            case TagConstant.TAG_COMPUTE_TYPE_EQ:
                request.setEqualNum(Integer.parseInt(val));
                request.setNumberType(NumberType.eq);
                break;
            case TagConstant.TAG_COMPUTE_TYPE_BETWEEN:
                String[] vals=val.split(",");
                request.setBeginNum(Integer.parseInt(vals[0]));
                request.setEndNum(Integer.parseInt(vals[1]));
                request.setNumberType(NumberType.between);
                break;
            default:break;
        }
    }

    private static void setStatisticsTypeHandle(AbstractFilterRequest request, String key, String val){
        String[] keys=key.split("flag");
        String[] vals=val.split(",");
        switch (keys[0]){
            case TagConstant.TAG_STATISTICS_CHANNEL:
                request.setStatisticsType(StatisticsType.CHANNEL);
                request.setStatisticsValList(Arrays.asList(vals));
                break;
            case TagConstant.TAG_STATISTICS_COMMODITY_BRAND:
                request.setStatisticsType(StatisticsType.COMMODITYBRAND);
                request.setStatisticsValList(Arrays.asList(vals));
                break;
            case TagConstant.TAG_STATISTICS_MCU_INFO:
                request.setStatisticsType(StatisticsType.MCUINFO);
                request.setStatisticsValList(Arrays.asList(vals));
                break;
            default:break;
        }
    }

    private static void setDomainHandle(AbstractFilterRequest request, String key, String val){
        switch (key){
            case TagConstant.TAG_DOMAIN_ECU_INFO:
                request.setDomainType(DomainType.ECU_INFO);
                break;
            case TagConstant.TAG_DOMAIN_ACU_INFO:
                request.setDomainType(DomainType.ACU_INFO);
                break;
            case TagConstant.TAG_DOMAIN_SCU_INFO:
                request.setDomainType(DomainType.SCU_INFO);
                break;
            case TagConstant.TAG_DOMAIN_MCU_INFO:
                request.setDomainType(DomainType.MCU_INFO);
                break;
            default:break;
        }
        String[] vals=val.split(",");
        request.setCuVals(Arrays.asList(vals));
    }
}
