package com.gic.spark.util;

import com.gic.spark.datasource.mysql.MysqlDatasource;
import com.google.common.base.Joiner;
import org.apache.spark.sql.Dataset;
import org.apache.spark.sql.Row;
import org.apache.spark.sql.SparkSession;
import org.apache.spark.sql.types.StructField;

import java.util.ArrayList;
import java.util.List;

/**
 * Created by paste on 2018/7/27 14:51
 * <p>
 * TODO: class description
 */
public class HivePartitionUtil {

    public static void saveDatasetToPartitionTable(SparkSession sparkSession, Dataset<Row> dataset, String targetTable) {

        if (!SparkHiveUtil.isFieldMatch(dataset, sparkSession.table(targetTable))) {
            dataset.printSchema();
            throw new RuntimeException("save into partition table error: fields dismatch " + targetTable);
        }

        System.out.println("hiveMetastoreDatasource.Schema==>"+ MysqlDatasource.hiveMetastoreDatasource.getSchema());
        System.out.println("hiveMetastoreDatasource.JdbcUrl==>"+ MysqlDatasource.hiveMetastoreDatasource.getJdbcUrl());
        System.out.println("hiveMetastoreDatasource.User==>"+ MysqlDatasource.hiveMetastoreDatasource.getUser());
        System.out.println("hiveMetastoreDatasource.Password==>"+ MysqlDatasource.hiveMetastoreDatasource.getPassword());

        List<String> partitionColumns = SparkHiveUtil.getHiveTablePartitionColumns(targetTable);

        if (partitionColumns.size() == 0) {
            throw new RuntimeException("target table is not paritioned: " + targetTable);
        }
        List<String> columns = new ArrayList();

        for (StructField structField : dataset.schema().fields()) {
            if (!partitionColumns.contains(structField.name().toLowerCase()))
                columns.add(structField.name());
        }

        columns.addAll(partitionColumns);

        dataset.createOrReplaceTempView("tmp_table");

        // generate sql

        sparkSession.sql(String.format("INSERT overwrite table %s\n" +
                "PARTITION (%s) SELECT %s from tmp_table", targetTable, Joiner.on(",").join(partitionColumns), Joiner.on(",").join(columns)));

        System.out.println(targetTable+" table write finish !");
    }

}
