package com.gic.spark.util;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import org.apache.http.*;
import org.apache.http.client.ClientProtocolException;
import org.apache.http.client.entity.UrlEncodedFormEntity;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.conn.ClientConnectionManager;
import org.apache.http.conn.params.ConnManagerParams;
import org.apache.http.conn.params.ConnPerRouteBean;
import org.apache.http.conn.scheme.PlainSocketFactory;
import org.apache.http.conn.scheme.Scheme;
import org.apache.http.conn.scheme.SchemeRegistry;
import org.apache.http.conn.ssl.SSLSocketFactory;
import org.apache.http.entity.StringEntity;
import org.apache.http.impl.client.DefaultHttpClient;
import org.apache.http.impl.conn.tsccm.ThreadSafeClientConnManager;
import org.apache.http.message.BasicNameValuePair;
import org.apache.http.params.BasicHttpParams;
import org.apache.http.params.HttpConnectionParams;
import org.apache.http.params.HttpParams;
import org.apache.http.params.HttpProtocolParams;
import org.apache.http.protocol.HTTP;
import org.apache.http.util.EntityUtils;
import org.apache.log4j.Logger;
import scala.Tuple2;

import java.io.*;
import java.net.ConnectException;
import java.net.HttpURLConnection;
import java.net.URL;
import java.net.URLDecoder;
import java.util.*;
import java.util.Map.Entry;

public class HttpClient {
    private static Logger logger = Logger.getLogger(HttpClient.class);

    private static org.apache.http.client.HttpClient mHttpClient;

    public static final int DEFAULT_MAX_CONNECTIONS = 200;
    public static final int DEFAULT_SOCKET_TIMEOUT = 10 * 1000;
    public static final int DEFAULT_CONNECT_TIMEOUT = 30 * 1000;
    public static final int DEFAULT_SOCKET_BUFFER_SIZE = 8192;

    protected static synchronized org.apache.http.client.HttpClient getHttpClient() {
        if (null == mHttpClient) {
            HttpParams params = new BasicHttpParams();
            HttpProtocolParams.setVersion(params, HttpVersion.HTTP_1_1);
            HttpProtocolParams.setContentCharset(params, HTTP.UTF_8);

            ConnManagerParams.setTimeout(params, DEFAULT_SOCKET_TIMEOUT);
            ConnManagerParams.setMaxConnectionsPerRoute(params, new ConnPerRouteBean(DEFAULT_MAX_CONNECTIONS));
            ConnManagerParams.setMaxTotalConnections(params, DEFAULT_MAX_CONNECTIONS);

            HttpConnectionParams.setConnectionTimeout(params, DEFAULT_CONNECT_TIMEOUT);
            HttpConnectionParams.setSoTimeout(params, DEFAULT_SOCKET_TIMEOUT);
            HttpConnectionParams.setTcpNoDelay(params, true);
            HttpConnectionParams.setSocketBufferSize(params, DEFAULT_SOCKET_BUFFER_SIZE);

            SchemeRegistry schReg = new SchemeRegistry();
            schReg.register(new Scheme("http", PlainSocketFactory.getSocketFactory(), 80));
            schReg.register(new Scheme("https", SSLSocketFactory.getSocketFactory(), 443));

            ClientConnectionManager conMgr = new ThreadSafeClientConnManager(params, schReg);
            mHttpClient = new DefaultHttpClient(conMgr, params);

        }

        org.apache.http.client.CookieStore cookieStore = ((DefaultHttpClient) mHttpClient).getCookieStore();
        cookieStore.clear();

        return mHttpClient;
    }

    public static Map<String, Object> getWinxinResByJson(String url,
                                                         String jsonStr) {
        return getWinxinResByJson(url, jsonStr, null);
    }

    public static Map<String, Object> getWinxinResByJson(String url,
                                                         String jsonStr, Map<String, String> header) {

        long begin = new Date().getTime();
        String resInfo = null;
        Map<String, Object> weixinMap = new HashMap<String, Object>();
        org.apache.http.client.HttpClient client = getHttpClient();
        HttpPost post = new HttpPost(url);
        StringBuilder builder = new StringBuilder();

        if (null != header) {
            for (Entry<String, String> entry : header.entrySet()) {
                post.addHeader(entry.getKey(), entry.getValue());
            }
        }

        try {

            if (null != jsonStr) {
                post.setEntity(new StringEntity(jsonStr, "utf-8"));
            }
            HttpResponse response = client.execute(post);
            resInfo = EntityUtils.toString(response.getEntity(), "utf-8");

            weixinMap = JSON.parseObject(resInfo, Map.class);
        } catch (UnsupportedEncodingException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        } catch (ClientProtocolException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        } catch (IOException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        } finally {
            long end = new Date().getTime();
            logger.info("call-res cost:" + (end - begin) + " url:" + url
                    + " param:" + jsonStr + " res:" + resInfo);
        }
        return weixinMap;
    }

    public static Object getWinxinResByJsonToObj(String url, String jsonStr,
                                                 Class clazz) {
        return getWinxinResByJsonToObj(url, jsonStr, clazz, "POST");
    }

    public static Object getWinxinResByJsonToObj(String url, String jsonStr,
                                                 Class clazz, String method) {

        long begin = new Date().getTime();
        String resInfo = null;
        Object obj = null;
        org.apache.http.client.HttpClient client = getHttpClient();

        HttpResponse response = null;

        try {
            if ("POST".equals(method)) {
                HttpPost post = new HttpPost(url);
                if (null != jsonStr) {
                    post.setEntity(new StringEntity(jsonStr, "utf-8"));
                }
                response = client.execute(post);
            }
            if ("GET".equals(method)) {
                HttpGet get = new HttpGet(url);
                response = client.execute(get);
            }

            resInfo = EntityUtils
                    .toString(response.getEntity(), "utf-8");

            obj = JSON.parseObject(resInfo, clazz);
        } catch (UnsupportedEncodingException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        } catch (ClientProtocolException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        } catch (IOException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        } finally {
            long end = new Date().getTime();
            logger.info("call-res cost:" + (end - begin) + " url:" + url
                    + " param:" + jsonStr + " res:" + resInfo);
        }
        return obj;
    }


    public static Map<String, Object> getWinxinRes(String url,
                                                   Map<String, String> map) {
        Object obj = getWinxinRes(url, map, Map.class, "POST");
        if (null != obj)
            return (Map<String, Object>) obj;
        return null;
    }

    public static Map<String, Object> getWinxinRes(String url,
                                                   Map<String, String> map, String method) {
        Object obj = getWinxinRes(url, map, Map.class, method);
        if (null != obj)
            return (Map<String, Object>) obj;
        return null;
    }

    public static Object getWinxinRes(String url, Map<String, String> map,
                                      Class clazz) {

        return getWinxinRes(url, map, clazz, "POST");
    }

    public static Object getWinxinRes(String url, Map<String, String> map,
                                      Class clazz, String method) {
        long begin = System.currentTimeMillis();

        String entityStr = null;
        Object obj = null;
        org.apache.http.client.HttpClient client = getHttpClient();
        HttpResponse response = null;
        try {
            if ("POST".equals(method)) {
                HttpPost post = new HttpPost(url);
                List<NameValuePair> nvps = new ArrayList<NameValuePair>();
                Iterator<String> iterator = map.keySet().iterator();
                while (iterator.hasNext()) {
                    String keyString = iterator.next();
                    nvps.add(new BasicNameValuePair(keyString, map
                            .get(keyString)));
                }
                post.setEntity((HttpEntity) new UrlEncodedFormEntity(nvps,
                        "UTF-8"));
                response = client.execute(post);
            }
            if ("GET".equals(method)) {
                if (map != null) {
                    if (map.size() > 0) {
                        if (url.indexOf("?") > 0)
                            url = url + "&";
                        else
                            url = url + "?";
                    }
                    Iterator<String> iterator = map.keySet().iterator();
                    while (iterator.hasNext()) {
                        String keyString = iterator.next();
                        url = url + keyString + "=" + map.get(keyString) + "&";
                    }
                    if (map.size() > 0)
                        url = url.substring(0, url.length() - 1);
                }
                HttpGet get = new HttpGet(url);
                response = client.execute(get);
            }
            entityStr = EntityUtils.toString(response.getEntity(), "utf-8");
            obj = JSON.parseObject(entityStr, clazz);
        } catch (Exception e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
            return null;
        } finally {
            long end = System.currentTimeMillis();
            logger.info("call-res cost:" + (end - begin) + " url:" + url
                    + " param:" + map + " res:" + entityStr);
        }
        return obj;
    }

    public static Map<String, Object> getWinxinResToStream(String url) {

        return getWinxinResToStream(url, "POST");
    }

    public static Map<String, Object> getWinxinResToStream(String url,
                                                           String method) {

        Map<String, Object> res = new HashMap<String, Object>();

        byte[] content = null;
        List<byte[]> contentList = new ArrayList<byte[]>();
        org.apache.http.client.HttpClient client = getHttpClient();

        HttpResponse response = null;
        InputStream is = null;
        String fileName = null;
        try {
            if ("POST".equals(method)) {
                HttpPost post = new HttpPost(url);
                response = client.execute(post);
            }
            if ("GET".equals(method)) {
                HttpGet get = new HttpGet(url);
                response = client.execute(get);
            }
            for (Header header : response.getAllHeaders()) {
                String info = header.getValue();
                if (info.contains("filename="))
                    fileName = URLDecoder.decode(
                            info.substring(info.indexOf("filename=") + 9),
                            "UTF-8");
            }
            HttpEntity entity = response.getEntity();
            is = entity.getContent();
            byte[] arr = new byte[1024];
            int len = 0;
            int sumlen = 0;
            while ((len = is.read(arr)) != -1) {
                sumlen = sumlen + len;
                int begin = 0;
                byte[] info = new byte[len];
                for (byte b : arr) {
                    if (begin < len) {
                        info[begin] = b;
                    } else {
                        break;
                    }
                    begin++;
                }
                contentList.add(info);
            }
            content = new byte[sumlen];
            int index = 0;
            for (byte[] bt : contentList) {
                for (byte b : bt) {
                    content[index] = b;
                    index++;
                }
            }
        } catch (Exception e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        } finally {
            if (null != is)
                try {
                    is.close();
                } catch (IOException e) {
                    // TODO Auto-generated catch block
                    e.printStackTrace();
                    return null;
                }
            res.put("content", content);
            res.put("fileName", fileName);
            return res;
        }
    }


    public static Map<String, Object> getHttpByPost(String url,
                                                    Map<String, String> map) {
        List<NameValuePair> nvps = new ArrayList<NameValuePair>();
        Iterator<String> iterator = map.keySet().iterator();
        while (iterator.hasNext()) {
            String keyString = iterator.next();
            nvps.add(new BasicNameValuePair(keyString, map.get(keyString)));
        }
        return getHttpByPost(url, nvps);
    }

    public static Map<String, Object> getHttpByPost(String url,
                                                    String[]... params) {
        List<NameValuePair> nvps = new ArrayList<NameValuePair>();
        if (params != null) {
            for (String[] param : params) {

                nvps.add(new BasicNameValuePair(param[0], param[1]));
            }
        }
        return getHttpByPost(url, nvps);
    }

    /**
     * 请求返回状态码code 和 结果 result
     */
    public static Map<String, Object> getHttpByPost(String url,
                                                    List<NameValuePair> nvps) {
        Map<String, Object> map = new HashMap<String, Object>();
        org.apache.http.client.HttpClient client = getHttpClient();

        HttpPost post = new HttpPost(url);

        StringBuilder builder = new StringBuilder();
        String result = null;
        String responseStr = "";
        int responseCode = 0;

        try {
            post.setEntity((HttpEntity) new UrlEncodedFormEntity(nvps, "UTF-8"));
            HttpResponse response = client.execute(post);
            map = doResponse(response);
        } catch (UnsupportedEncodingException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        } catch (ClientProtocolException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        } catch (IOException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        }
        return map;

    }

    public static Map<String, Object> getHttpByGet(String url) {
        Map<String, Object> map = new HashMap<String, Object>();
        org.apache.http.client.HttpClient client = getHttpClient();
        HttpGet get = new HttpGet(url);
        List<NameValuePair> nvps = new ArrayList<NameValuePair>();
        try {
            logger.error("url:" + url);
            HttpResponse response = client.execute(get);

            map = doResponse(response);
        } catch (ClientProtocolException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        } catch (IOException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        }
        return map;

    }

    public static HttpResponse getHttpResponseByGet(String url) {
        org.apache.http.client.HttpClient client = getHttpClient();
        HttpGet get = new HttpGet(url);
        try {
            logger.error("url:" + url);
            HttpResponse response = client.execute(get);
            return response;
        } catch (ClientProtocolException e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        }
        return null;
    }

    public static String getResponseString(HttpResponse response) {
        String line = "";
        String result = null;
        String responseStr = "";
        int responseCode = 0;
        try {

            HttpEntity entity = response.getEntity();

            BufferedReader reader = new BufferedReader(new InputStreamReader(
                    entity.getContent(), "UTF-8"), 8 * 1024);

            StringBuilder builder = new StringBuilder();

            responseCode = response.getStatusLine().getStatusCode();

            switch (responseCode) {
                // 请求成功
                case HttpURLConnection.HTTP_OK:
                    while ((line = reader.readLine()) != null) {
                        builder.append(line);
                    }
                    responseStr = builder.toString();
                    result = "请求成功";
                    break;
                case HttpURLConnection.HTTP_BAD_REQUEST:
                    while ((line = reader.readLine()) != null) {
                        builder.append(line);
                    }
                    responseStr = builder.toString();
                    result = "错误请求";
                    break;
                case HttpURLConnection.HTTP_INTERNAL_ERROR:
                    result = "服务器端错误";
                    break;
                case HttpURLConnection.HTTP_NOT_FOUND:
                    result = "未找到指定的网址";
                    break;
                case HttpURLConnection.HTTP_BAD_GATEWAY:
                    result = "请求超时";
                    break;
                default:
                    break;
            }

        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            logger.info("result:" + result);
            logger.info("responseStr:" + responseStr);
            logger.info("responseCode:" + responseCode);
            System.out.println("result:" + result);
            System.out.println("responseStr:" + responseStr);
            System.out.println("responseCode:" + responseCode);
        }

        return responseStr;
    }

    private static Map<String, Object> doResponse(HttpResponse response) {
        Map<String, Object> map = new HashMap<String, Object>();
        String line = "";
        String result = null;
        String responseStr = "";
        int responseCode = 0;
        try {

            HttpEntity entity = response.getEntity();

            BufferedReader reader = new BufferedReader(new InputStreamReader(
                    entity.getContent(), "UTF-8"), 8 * 1024);

            StringBuilder builder = new StringBuilder();

            responseCode = response.getStatusLine().getStatusCode();

            switch (responseCode) {
                // 请求成功
                case HttpURLConnection.HTTP_OK:
                    while ((line = reader.readLine()) != null) {
                        builder.append(line);
                    }
                    responseStr = builder.toString();
                    result = "请求成功";
                    break;
                case HttpURLConnection.HTTP_BAD_REQUEST:
                    while ((line = reader.readLine()) != null) {
                        builder.append(line);
                    }
                    responseStr = builder.toString();
                    result = "错误请求";
                    break;
                case HttpURLConnection.HTTP_INTERNAL_ERROR:
                    result = "服务器端错误";
                    break;
                case HttpURLConnection.HTTP_NOT_FOUND:
                    result = "未找到指定的网址";
                    break;
                case HttpURLConnection.HTTP_BAD_GATEWAY:
                    result = "请求超时";
                    break;
                default:
                    break;
            }

        } catch (Exception e) {
            e.printStackTrace();
            map.put("code", HttpURLConnection.HTTP_BAD_GATEWAY);
            map.put("result", "无法连接网络，请检查网络设置");
            map.put("response", "");
        } finally {
            map.put("code", responseCode);
            map.put("result", result);
            map.put("response", responseStr);
            logger.info("result:" + result);
            logger.info("responseStr:" + responseStr);
            logger.info("responseCode:" + responseCode);
            System.out.println("result:" + result);
            System.out.println("responseStr:" + responseStr);
            System.out.println("responseCode:" + responseCode);
        }

        return map;
    }

    private static String getTransId(String appKey) {
        StringBuffer buf = new StringBuffer();
        buf.append(appKey);
        buf.append(DateUtil.formatString(new Date(),
                DateUtil.FORMAT_DATETIME_18));
        return buf.toString();
    }


    public static String getWinxinResinfo(String url, Map<String, String> map,
                                          String method) {
        long begin = new Date().getTime();
        String entityStr = "";
        org.apache.http.client.HttpClient client = getHttpClient();
        HttpResponse response = null;
        try {

            if ("POST".equals(method)) {
                HttpPost post = new HttpPost(url);
                List<NameValuePair> nvps = new ArrayList<NameValuePair>();
                Iterator<String> iterator = map.keySet().iterator();
                while (iterator.hasNext()) {
                    String keyString = iterator.next();
                    nvps.add(new BasicNameValuePair(keyString, map
                            .get(keyString)));
                }
                post.setEntity((HttpEntity) new UrlEncodedFormEntity(nvps,
                        "UTF-8"));
                response = client.execute(post);
            }
            if ("GET".equals(method)) {
                if (map != null) {
                    if (map.size() > 0) {
                        if (url.indexOf("?") > 0)
                            url = url + "&";
                        else
                            url = url + "?";
                    }
                    Iterator<String> iterator = map.keySet().iterator();
                    while (iterator.hasNext()) {
                        String keyString = iterator.next();
                        url = url + keyString + "=" + map.get(keyString) + "&";
                    }
                    if (map.size() > 0)
                        url = url.substring(0, url.length() - 1);
                }
                HttpGet get = new HttpGet(url);
                response = client.execute(get);
            }
            entityStr = EntityUtils.toString(response.getEntity(), "utf-8");

        } catch (Exception e) {
            e.printStackTrace();
            return null;
        } finally {
            long end = new Date().getTime();
            logger.info("call-res cost:" + (end - begin) + " url:" + url
                    + " param:" + map + " res:" + entityStr);
        }
        return entityStr;
    }


    /**
     * 请求
     *
     * @Title: httpRequest
     * @Description: TODO
     * @Param @param requestUrl
     * @Param @param requestMethod
     * @Param @param outputStr
     * @Param @return
     * @Return JSONObject
     * @Throws
     */
    public static String httpRequest(String requestUrl, String requestMethod, String outputStr) {
        try {
            URL url = new URL(requestUrl);
            HttpURLConnection conn = (HttpURLConnection) url.openConnection();
            conn.setDoOutput(true);
            conn.setDoInput(true);
            conn.setUseCaches(false);
            conn.setRequestMethod(requestMethod);
            if (null != outputStr) {
                OutputStream outputStream = conn.getOutputStream();
                outputStream.write(outputStr.getBytes("UTF-8"));
                outputStream.close();
            }
            InputStream inputStream = conn.getInputStream();
            InputStreamReader inputStreamReader = new InputStreamReader(inputStream, "utf-8");
            BufferedReader bufferedReader = new BufferedReader(inputStreamReader);
            String str = null;
            StringBuffer buffer = new StringBuffer();
            while ((str = bufferedReader.readLine()) != null) {
                buffer.append(str);
            }
            bufferedReader.close();
            inputStreamReader.close();
            inputStream.close();
            inputStream = null;
            conn.disconnect();
            return buffer.toString();
        } catch (ConnectException ce) {
            ce.printStackTrace();
        } catch (Exception e) {
            e.printStackTrace();
        }
        return null;
    }

    public static String getESIindexName(String esIndexnameUrl,String enterprise_id,String code){
        String esIndexName="";
        HttpResponse response=getHttpResponseByGet(esIndexnameUrl+"getEsNameAlias.json?enterpriseId="+enterprise_id+"&code="+code);
        int responseCode = response.getStatusLine().getStatusCode();
        if(responseCode==200){
            JSONObject jsonObject = JSONObject.parseObject(HttpClient.getResponseString(response));
            Map result=(Map)jsonObject.get("response");
            int errcode=(Integer) result.get("errcode");
            if(errcode==1){
                esIndexName= (String) result.get("name");
            }
        }
        return esIndexName;
    }

    public static List<String> getEsColumns(String esIndexnameUrl,String enterprise_id){
        List<String> columnList=null;
        HttpResponse response=getHttpResponseByGet(esIndexnameUrl+"getEsColumns.json?enterpriseId="+enterprise_id+"&code=member");
        int responseCode = response.getStatusLine().getStatusCode();
        if(responseCode==200){
            JSONObject jsonObject = JSONObject.parseObject(HttpClient.getResponseString(response));
            Map result=(Map)jsonObject.get("response");
            int code=(Integer) result.get("errcode");
            if(code==1){
                columnList= (List<String>) result.get("list");
            }
        }
        return columnList;
    }

    public static String parseSelectData(String parseSelectDataUrl, String enterpriseId, String params, Tuple2<String,String> userGroupTp2){
        Map<String, String> paramMap=new HashMap();
        paramMap.put("enterpriseId",enterpriseId);
        paramMap.put("params",params);
        paramMap.put("createUser",null!=userGroupTp2?userGroupTp2._1():null);
        paramMap.put("createTime",null!=userGroupTp2?userGroupTp2._2():null);
        Map<String, Object> resultMap=getHttpByPost(parseSelectDataUrl,paramMap);
        int responseCode = (Integer) resultMap.get("code");
        if(responseCode==200){

            return JSON.parseObject((String) resultMap.get("response")).get("result").toString();
        }
        return null;
    }

    public static void main(String[] args) throws Exception {
//
        /*String indexName=getESIindexName("ff8080815dacd3a2015dacd3ef5c0000");
        System.out.println("indexName===>"+indexName!=null&&!"".equals(indexName)?indexName:"");
//      ff808081593917d90159398ec6340012,ff8080815dacd3a2015dacd3ef5c0000
       List<String>columnList=getEsColumns("ff808081593917d90159398ec6340012");
       for(String column:columnList){
           System.out.println("column---->"+column);
       }*/

     /*  String enterpriseIds="1af58390681811e69d0818c58a146fd2,ff80808159678c0701597688028712bf,ff8080815d45ca76015d5ee0af746cc1,ff8080815fdefba4016010cf67c67219,ff80808160511d17016052c1ca79011c,ff80808160cc21c60160d4913f6f30eb,ff8080816133373a01614077beef7202,ff8080816170e2970161f626826b5990,ff8080816170e2970161f63d4ee75b38,ff8080816170e8990161bb8939ea2371,ff8080816170e8990161f65038745e4e,ff8080816170e8990161f65d60085f23,ff8080816170e8990161f66a272a5fe4,ff8080816170e8990161f6736b4c6033,ff8080816170e8990161f6809a4b609b,ff80808162ba2ac70162cdb5c96e114c,ff80808162ba2fdc0162cdbdf8501506,ff80808163218df301632667bd070028,ff8080816398cce0016398ceeb1b0000,ff80808163a84edb0163aee389832ed4,ff80808163e576c201641c87e3d72b49,ff808081646228b90164686efd0e0b4d,ff808081647fab8701648314a69d00a6,ff808081647fab870164831aa1e400ac,ff808081647fadb701648301c7fd01c7,ff808081647fadb70164870b048702b3,ff808081647faff301648317812600c7,ff808081647fb14f0164832989b400a0,ff808081647fb14f0164916473b7029b,ff808081647fb14f016492d87cd60304,ff8080816494494b0164a76b553a00e5,ff80808164c7d07f0164d97ce6c6060b,ff80808164c7d07f0164ef42ac780f92,ff80808164f65d9501651798e0f8143d,ff80808164f65e7e0165140abae4125a,ff80808164f660f9016522cb6f1d163e,ff80808166c07a6e0166c7e1dc7d02a3,ff808081677a6d8601677d7b18cf0284,ff80808167d1d41a0167e31539032198,ff80808167f5763e01682d6ca67e136e,ff8080816833414c01684b5a22e3203f,ff80808168f1fb740169380aa3e955a8,ff80808168f1fcf3016937fedfee56a5,ff80808168f1fd7301693805305c562c,ff80808169728b59016974f116f2008c,ff80808169728b59016974f700fc0093";
        List<String> enterpriseIdList = new ArrayList<>(Arrays.asList(enterpriseIds.split(",")));
        for(String enterpriseId:enterpriseIdList){
           *//* List<String>columnList=getEsColumns(enterpriseId);
            if(null != columnList&&columnList.size()>0){
//                System.out.println("enterpriseId==>"+enterpriseId);
            }else{
                System.err.println("error:enterpriseId==>"+enterpriseId);
            }*//*

        }*/


       /* HttpClient client = new HttpClient();
        String url = "http://localhost:8080/gic/storegroup_list"; // http请求所访问的地址

        Map<String, String> reqData = new HashMap<String, String>();
        // 发送请求包
        Map<String, Object> respData = client.getHttpByPost(url, reqData);
        String responseInfo = (String) respData.get("response");
        logger.info("resp:");
        logger.info(responseInfo);*/

        /*MemberIndexDocDTO dto=new MemberIndexDocDTO();
        Field[] fields=dto.getClass().getDeclaredFields();
        for(Field f:fields){
            System.out.println(f.getName());
        }*/


        String indexName=getESIindexName("http://gicdev.demogic.com/screening/","ff8080815dacd3a2015dacd3ef5c0000","member");
        System.out.println(indexName);
    }
}
